@@ -208,7 +208,7 @@ class ABI_EXPORT GR_Graphics
 									UT_GrowBufElement* pWidths);
 
 	virtual UT_uint32 measureUnRemappedChar(const UT_UCSChar c) = 0;
-	virtual void getCoverage(UT_Vector& coverage) = 0;
+	virtual void getCoverage(UT_NumberVector& coverage) = 0;
 #endif
 	
 	/* GR_Font versions of the above -- TODO: should I add drawChar* methods too? */
@@ -216,6 +216,7 @@ class ABI_EXPORT GR_Graphics
 	virtual UT_uint32 getFontDescent(GR_Font *) PURE_VIRTUAL_IF_NOT_PANGO;
 	virtual UT_uint32 getFontHeight(GR_Font *)  PURE_VIRTUAL_IF_NOT_PANGO;
 
+
 #ifndef WITH_PANGO
 	UT_uint32         getMaxCharacterWidth(const UT_UCSChar*s, UT_uint32 Length);
 #else
@@ -536,23 +537,4 @@ void xorRect(GR_Graphics* pG, const UT_Rect& r);
 void flash(GR_Graphics* pG, const UT_Rect& r, const UT_RGBColor& c);
 #endif
 
-class ABI_EXPORT GR_GraphicsFactory
-{
-public:
-
-	virtual ~GR_GraphicsFactory ()
-		{
-		}
-
-	virtual GR_Graphics* getGraphics() = 0;
-
-protected:
-	GR_GraphicsFactory ();
-
-private:
-
-	GR_GraphicsFactory(const GR_GraphicsFactory & other);
-	GR_GraphicsFactory& operator=(const GR_GraphicsFactory & other);
-};
-
 #endif /* GR_GRAPHICS_H */
