@@ -1,5 +1,5 @@
 /* AbiSource Program Utilities
- * Copyright (C) 1998-2001 AbiSource, Inc.
+ * Copyright (C) 1998-2000 AbiSource, Inc.
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -10,7 +10,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * bool UT_isRegularFile(const char* filename);
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
@@ -19,11 +19,23 @@
  
 #ifndef UT_PATH_H
 #define UT_PATH_H
-bool UT_isRegularFile(const char* filename);
-const char* UT_basename(const char* path);
 
-bool UT_directoryExists(const char* dir);
+#include <time.h>
 
-bool UT_isRegularFile(const char* filename);
+/* pre-emptive dismissal; ut_types.h is needed by just about everything,
+ * so even if it's commented out in-file that's still a lot of work for
+ * the preprocessor to do...
+ */
+#ifndef UT_TYPES_H
+#include "ut_types.h"
+#endif
+
+ABI_EXPORT const char* UT_basename(const char* path);
+
+ABI_EXPORT bool UT_directoryExists(const char* dir);
+
+ABI_EXPORT bool UT_isRegularFile(const char* filename);
+
+ABI_EXPORT time_t UT_mTime(const char* path);
 
 #endif /* UT_PATH_H */
