@@ -545,6 +545,7 @@ void UT_UTF8Stringbuf::escapeXML ()
 		{
 			if ((*ptr == '<') || (*ptr == '>')) incr += 3;
 			else if (*ptr == '&') incr += 4;
+			else if (*ptr == '"') incr += 5;
 			ptr++;
 		}
 	bool bInsert = grow (incr);
@@ -579,6 +580,15 @@ void UT_UTF8Stringbuf::escapeXML ()
 						}
 					else *ptr++ = '?';
 				}
+			else if (*ptr == '"')
+				{
+					if (bInsert)
+						{
+							*ptr++ = '&';
+							insert (ptr, "quot;", 5);
+						}
+					else *ptr++ = '?';
+				}
 			else ptr++;
 		}
 }
