@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
-/* $Id: xap_Cocoa_NSTableUtils.h,v 1.4 2003/07/02 22:56:34 hub Exp $ */
+/* $Id: xap_Cocoa_NSTableUtils.h,v 1.4.2.1 2003/09/30 12:29:11 hub Exp $ */
 
 #import <Cocoa/Cocoa.h>
 #include "ut_string_class.h"
@@ -32,7 +32,7 @@
 
 - (void)insertString:(NSString*)string atIndex:(int)index;
 - (void)addString:(NSString*)string;
-- (void)addUT_String:(const UT_String &)string;
+- (void)addUT_UTF8String:(const UT_UTF8String &)string;
 - (int)rowWithCString:(const char *)cString;
 - (void)removeAllStrings;
 - (NSArray*)array;
