@@ -138,7 +138,7 @@ GtkWidget * XAP_UnixDialog_Encoding::_constructWindow(void)
 	m_windowMain = glade_xml_get_widget(xml, "xap_UnixDlg_Encoding");
 	m_listEncodings = glade_xml_get_widget(xml, "encodingList");
 
-	gtk_window_set_title (GTK_WINDOW(m_windowMain), pSS->getValueUTF8(XAP_STRING_ID_DLG_UENC_EncTitle).c_str());
+	gtk_window_set_title (GTK_WINDOW(m_windowMain), pSS->getValueUTF8(XAP_STRING_ID_DLG_UENC_EncTitle).utf8_str());
 	localizeLabelMarkup(glade_xml_get_widget(xml, "lblEncoding"), pSS, XAP_STRING_ID_DLG_UENC_EncLabel);
 
 	// add a column to our TreeViews
