@@ -20,6 +20,8 @@
  */
 
 #include <gtk/gtk.h>
+#undef GTK_DISABLE_DEPRECATED
+#include <gtk/gtkoptionmenu.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -508,8 +510,8 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 
 	bool bCheckWritePermission = false;
 
-	UT_String szTitle = NULL;
-        UT_String szFileTypeLabel = NULL;
+	UT_UTF8String szTitle;
+	UT_UTF8String szFileTypeLabel;
 	switch (m_id)
 	{
 		case XAP_DIALOG_ID_INSERT_PICTURE:
@@ -572,7 +574,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	// NOTE: let GTK take care of the localization of the actual
 	// NOTE: buttons and labels on the FileSelection dialog.
 	
-	GtkFileSelection *pFS = GTK_FILE_SELECTION(gtk_file_selection_new(szTitle.c_str()));
+	GtkFileSelection *pFS = GTK_FILE_SELECTION(gtk_file_selection_new(szTitle.utf8_str()));
 	m_FS = pFS;
 
 	abiSetupModalDialog(GTK_DIALOG(pFS), pFrame, this, GTK_RESPONSE_CANCEL);
@@ -600,7 +602,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		    gtk_widget_show (preview);
 		    m_preview = preview;
 
-		    GtkWidget * frame = gtk_frame_new (pSS->getValueUTF8(XAP_STRING_ID_DLG_IP_Activate_Label).c_str());
+		    GtkWidget * frame = gtk_frame_new (pSS->getValueUTF8(XAP_STRING_ID_DLG_IP_Activate_Label).utf8_str());
 			gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_NONE);
 		    gtk_widget_show (frame);
 		    gtk_container_add (GTK_CONTAINER(frame), preview);
@@ -619,7 +621,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		  }
 
 		// pulldown label
-		GtkWidget * filetypes_label = gtk_label_new(szFileTypeLabel.c_str());
+		GtkWidget * filetypes_label = gtk_label_new(szFileTypeLabel.utf8_str());
 		gtk_label_set_justify(GTK_LABEL(filetypes_label), GTK_JUSTIFY_RIGHT);
 		gtk_misc_set_alignment(GTK_MISC(filetypes_label), 1.0, 0.5);
 		gtk_widget_show(filetypes_label);
@@ -658,7 +660,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 			// Auto-detect is always an option, but a special one, so we use
 			// a pre-defined constant for the type, and don't use the user-supplied
 			// types yet.
-			g_snprintf(buffer, 1024, "%s", pSS->getValueUTF8(XAP_STRING_ID_DLG_FOSA_FileTypeAutoDetect).c_str());
+			g_snprintf(buffer, 1024, "%s", pSS->getValueUTF8(XAP_STRING_ID_DLG_FOSA_FileTypeAutoDetect).utf8_str());
 			thismenuitem = gtk_menu_item_new_with_label(buffer);
 			g_object_set_data(G_OBJECT(thismenuitem), "user_data", GINT_TO_POINTER(XAP_DIALOG_FILEOPENSAVEAS_FILE_TYPE_AUTO));
 			gtk_widget_show(thismenuitem);
@@ -844,10 +846,7 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	GR_Font * fnt = pGr->findFont("Times New Roman", "normal", "", "normal", "", "12pt");
 	pGr->setFont(fnt);
 
-	UT_String str( pSS->getValueUTF8(XAP_STRING_ID_DLG_IP_No_Picture_Label) );
-	int len = str.size () ;
-	UT_UCSChar * ucstext = new UT_UCSChar [len + 1]; 
-	UT_UCS4_strcpy_char (ucstext, str.c_str());
+	UT_UTF8String str(pSS->getValueUTF8(XAP_STRING_ID_DLG_IP_No_Picture_Label).utf8_str());
 
 	int answer = 0;
 
@@ -864,9 +863,9 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	if (!buf)
 	  {
 #ifndef WITH_PANGO 		  
-	    pGr->drawChars (ucstext, 0, len, pGr->tlu(12), pGr->tlu(35));
+	    pGr->drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(35));
 #else
-		pGr->drawCharsDirectly(ucstext,0,len,pGr->tlu(12),pGr->tlu(35));
+		pGr->drawCharsDirectly(str.ucs4_str().ucs4_str(),0,str.size(),pGr->tlu(12),pGr->tlu(35));
 #endif		
 	    goto Cleanup;
 	  }
@@ -875,19 +874,19 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	struct stat st;
 	if (!stat (buf, &st)) {
 		if (!S_ISREG(st.st_mode)) {
-#ifndef WITH_PANGO			
-			pGr->drawChars (ucstext, 0, len, pGr->tlu(12), pGr->tlu(35));
+#ifndef WITH_PANGO 		  
+			pGr->drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(35));
 #else
-			pGr->drawCharsDirectly(ucstext,0,len,pGr->tlu(12),pGr->tlu(35));
+			pGr->drawCharsDirectly(str.ucs4_str().ucs4_str(),0,str.size(),pGr->tlu(12),pGr->tlu(35));
 #endif		
 			goto Cleanup;
 		}
 	}
 	else {
-#ifndef WITH_PANGO		
-		pGr->drawChars (ucstext, 0, len, pGr->tlu(12), pGr->tlu(35));
+#ifndef WITH_PANGO 		  
+		pGr->drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(35));
 #else
-		pGr->drawCharsDirectly(ucstext,0,len,pGr->tlu(12),pGr->tlu(35));
+		pGr->drawCharsDirectly(str.ucs4_str().ucs4_str(),0,str.size(),pGr->tlu(12),pGr->tlu(35));
 #endif		
 		goto Cleanup;
 	}
@@ -901,10 +900,10 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	if ((errorCode != UT_OK) || !pIEG)
 	{
 		DELETEP(pBB);
-#ifndef WITH_PANGO		
-		pGr->drawChars (ucstext, 0, len, pGr->tlu(12), pGr->tlu(35));
+#ifndef WITH_PANGO 		  
+		pGr->drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(35));
 #else
-		pGr->drawCharsDirectly(ucstext,0,len,pGr->tlu(12),pGr->tlu(35));
+		pGr->drawCharsDirectly(str.ucs4_str().ucs4_str(),0,str.size(),pGr->tlu(12),pGr->tlu(35));
 #endif		
 		goto Cleanup;
 	}
@@ -913,10 +912,10 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 
 	if ((errorCode != UT_OK) || !pGraphic)
 	  {
-#ifndef WITH_PANGO		  
-	    pGr->drawChars (ucstext, 0, len, pGr->tlu(12), pGr->tlu(35));
+#ifndef WITH_PANGO 		  
+		pGr->drawChars (str.ucs4_str().ucs4_str(), 0, str.size(), pGr->tlu(12), pGr->tlu(35));
 #else
-	    pGr->drawCharsDirectly(ucstext,0,len,pGr->tlu(12),pGr->tlu(35));
+		pGr->drawCharsDirectly(str.ucs4_str().ucs4_str(),0,str.size(),pGr->tlu(12),pGr->tlu(35));
 #endif		
 	    goto Cleanup;
 	  }
@@ -954,7 +953,6 @@ gint XAP_UnixDialog_FileOpenSaveAs::previewPicture (void)
 	DELETEP(pImage);
 	DELETEP(pGr);
 	DELETEP(fnt);
-	DELETEPV(ucstext);
 	DELETEP(pIEG);
 	DELETEP(pGraphic);
 
