@@ -76,7 +76,7 @@ extern XAP_Dialog_MessageBox::tAnswer s_CouldNotLoadFileMessage(XAP_Frame * pFra
 */
 LRESULT CALLBACK s_rebarWndProc( HWND hWnd, UINT uMessage, WPARAM wParam, LPARAM lParam)
 {
-	switch (uMessage)
+	switch (uMessage)	
 	{		
 		case WM_DRAWITEM:
 		{
@@ -317,19 +317,20 @@ bool XAP_Win32FrameImpl::_close(void)
 	// last window closed is the one that the window state is stored from.
 	WINDOWPLACEMENT wndPlacement;
 	wndPlacement.length = sizeof(WINDOWPLACEMENT); // must do
+	
 	if (GetWindowPlacement(m_hwndFrame, &wndPlacement))
 	{
+		UT_uint32 nFlags = PREF_FLAG_GEOMETRY_POS | PREF_FLAG_GEOMETRY_SIZE;
+
+		if (wndPlacement.showCmd == SW_SHOWMAXIMIZED)
+			nFlags |= PREF_FLAG_GEOMETRY_MAXIMIZED;
+
 		XAP_App::getApp()->setGeometry(wndPlacement.rcNormalPosition.left, 
 				wndPlacement.rcNormalPosition.top, 
 				wndPlacement.rcNormalPosition.right - wndPlacement.rcNormalPosition.left,
-				wndPlacement.rcNormalPosition.bottom - wndPlacement.rcNormalPosition.top,
-				/* flag is meant for info about the position & size info stored, not a generic flag
-				 * TODO: figure out where to store this then, so we can max/min/normal again
-				wndPlacement.showCmd
-				*/
-				PREF_FLAG_GEOMETRY_POS | PREF_FLAG_GEOMETRY_SIZE
-		);
-	}
+				wndPlacement.rcNormalPosition.bottom - wndPlacement.rcNormalPosition.top,	
+				nFlags);
+	}	
 	else
 	{
 		// if failed to get placement then invalidate stored settings
@@ -802,11 +803,7 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 								hWndChild = FindWindowEx( pNMcd->hdr.hwndFrom, hWndChild, NULL, NULL );
 							}
 
-							if( hBr != NULL )
-							{
-								DeleteObject( hBr );
-								hBr = NULL;
-							}
+							/* Don't delete hBr since it was obtained using GetSysColorBrush, so System owned */
 						}
 						break;
 					}
