@@ -1,20 +1,20 @@
 /* AbiWord
  * Copyright (C) Luke Jordan, Martin Sevior.
  * BIDI Copyright (c) 2001,2002 Tomas Frydrych, Yaacov Akiba Slama
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
 
@@ -64,10 +64,12 @@ fl_AutoNum::fl_AutoNum(	UT_uint32 id,
 		m_pParentItem(0)
 {
 	_setParent(pParent);
+	memset(m_pszDelim, 0, 80);
+	memset(m_pszDecimal, 0, 80);
 	UT_uint32 i;
 	i =  UT_XML_strncpy( m_pszDelim, 80, lDelim);
 	i =  UT_XML_strncpy( m_pszDecimal, 80, lDecimal);
- 	addItem(pFirst);	
+ 	addItem(pFirst);
 
 	m_pDoc->addList(this);
 	// New 6/11/2000. m_pParentItem is the item in the parent list
@@ -96,6 +98,8 @@ fl_AutoNum::fl_AutoNum(	UT_uint32 id,
 		m_pParentItem(0)
 {
 	// Set in Block???
+	memset(m_pszDelim, 0, 80);
+	memset(m_pszDecimal, 0, 80);
 	UT_XML_strncpy( m_pszDelim, 80, lDelim);
 	UT_XML_strncpy( m_pszDecimal, 80, lDecimal);
 	if(m_iParentID != 0)
@@ -129,12 +133,12 @@ void fl_AutoNum::fixHierarchy(void)
 	UT_uint32 docParentID = 0;
 	if(m_pItems.getItemCount() >0)
 	{
-		PL_StruxDocHandle sdh = (PL_StruxDocHandle) m_pItems.getNthItem(0);
+		PL_StruxDocHandle sdh = static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(0));
 		bool bFound = m_pDoc->getAttributeFromSDH(sdh,PT_PARENTID_ATTRIBUTE_NAME,&pszParentID);
 		if(bFound)
 		{
 			docParentID= atoi(pszParentID);
-		} 
+		}
 	}
 	if((m_iID != 0) && (docParentID != 0) &&  (docParentID != m_iParentID) && (docParentID != m_iID))
 	{
@@ -180,11 +184,11 @@ static int compareListItems(const void* p1, const void* p2)
 {
 	//
 	// Fun with (void *) pointers!
-	// 
-	//	pf_Frag * pf1 = (pf_Frag *) p1;
+	//
+	//	pf_Frag * pf1 = static_cast<pf_Frag *>(p1);
 	//	PD_Document * pDoc = pf1->getPieceTable()->getDocument();
-	PL_StruxDocHandle * sdh1 = (PL_StruxDocHandle *) p1;
-	PL_StruxDocHandle * sdh2 = (PL_StruxDocHandle *) p2;
+	PL_StruxDocHandle const * sdh1 = reinterpret_cast<PL_StruxDocHandle const *>(p1);
+	PL_StruxDocHandle const * sdh2 = reinterpret_cast<PL_StruxDocHandle const *>(p2);
 	PT_DocPosition pos1 = pCurDoc->getStruxPosition(*sdh1);
 	PT_DocPosition pos2 = pCurDoc->getStruxPosition(*sdh2);
 	if(pos1 < pos2)
@@ -213,7 +217,7 @@ void    fl_AutoNum::markAsDirty(void)
 void    fl_AutoNum::findAndSetParentItem(void)
 {
 	if(m_iParentID == 0)
-	{		
+	{
 		return;
 	}
 	else if( m_pParent == NULL)
@@ -238,7 +242,7 @@ void    fl_AutoNum::findAndSetParentItem(void)
 	{
 		return;
 	}
-	PL_StruxDocHandle pCurFirst =  (PL_StruxDocHandle) m_pItems.getFirstItem();
+	PL_StruxDocHandle pCurFirst =  static_cast<PL_StruxDocHandle>(m_pItems.getFirstItem());
 	if(pCurFirst == NULL)
 		return;
 	PT_DocPosition posCur = m_pDoc->getStruxPosition(pCurFirst);
@@ -275,7 +279,7 @@ void    fl_AutoNum::findAndSetParentItem(void)
 //
 	if((m_pParent == NULL) || (posClosest == 0))
 	{
-		for(iList = 0; iList < cnt; iList++) 
+		for(iList = 0; iList < cnt; iList++)
 		{
 			fl_AutoNum * pParent = m_pDoc->getNthList(iList);
 			UT_uint32 i=0;
@@ -338,17 +342,18 @@ void    fl_AutoNum::findAndSetParentItem(void)
 		update(0);
 }
 
-void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint, 
+/*!
+ * This method recursively calculates a label based on the type of label
+ * of the AutoNum Class. This is output to the label string labelStr.
+ *
+ * insPoint is the position in the string where the new text goes. It starts
+ * Pointing to the byte == 0
+ * depth is the level of recursion
+ * pLayout is a pointer to the Layout item containing the current list item
+ */
+void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 								  UT_uint32 depth, PL_StruxDocHandle pLayout) const
 {
-	// This method recursively calculates a label based on the type of label
-	// of the AutoNum Class. This is output to the label string labelStr.
-	//
-	// insPoint is the position in the string where the new text goes. It starts
-	// Pointing to the byte == 0
-	// depth is the level of recursion
-	// pLayout is a pointer to the Layout item containing the current list item
-	//
     char p[100], leftDelim[10], rightDelim[10];
 	UT_uint32 i,psz;
 	//
@@ -365,30 +370,37 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 //		return;
 //	}
 
-	// TODO This is a bit of a hack to split the delim string. It would be 
+	// TODO This is a bit of a hack to split the delim string. It would be
 	// TODO nice to clear it up.
 
-	sprintf(p, "%s", m_pszDelim);
+	UT_XML_strncpy (p, sizeof(p), m_pszDelim);
 	UT_uint32 rTmp;
-	
+
 	i = 0;
 
-	while (p[i] && p[i] != '%' && p[i+1] != 'L')
+	while (i < NrElements(p) && p[i] && p[i] != '%' && p[i+1] != 'L')
 	{
+		// FIXME check the bounds to not overflow leftDelim
 		leftDelim[i] = p[i];
 		i++;
 	}
+	if (i >= NrElements(p) || p[i] == '\0') {
+		UT_ASSERT(UT_NOT_REACHED);
+		UT_DEBUGMSG (("Hub: not a delim (SHOULD NOT HAPPEN)!!!\n"));
+		*insPoint = 0;
+		return;
+	}
 	leftDelim[i] = '\0';
 	i += 2;
 	rTmp = i;
-	while (p[i] || p[i] != '\0')
+	while (i < NrElements(p) && p[i] || p[i] != '\0')
 	{
+		// FIXME check the bounds to not overflow rightDelim
 		rightDelim[i - rTmp] = p[i];
 		i++;
 	}
 	rightDelim[i - rTmp] = '\0';
-	//UT_DEBUGMSG(("Left Delim: %s, Right Delim: %s\n", leftDelim, rightDelim));
-	
+
 	if(m_pParent != NULL  && m_List_Type < BULLETED_LIST)
 	{
 		m_pParent->_getLabelstr( labelStr, insPoint, depth+1,getParentItem());
@@ -400,19 +412,19 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 				labelStr[(*insPoint)++] = CONV_TO_UCS m_pszDecimal[i];
 			}
 			(*insPoint)--;
-		}	       
+		}
 	}
-	
+
 	UT_sint32 place = getPositionInList(pLayout,depth);
 	if(place == -1)
 	{
 		//	       UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
-		labelStr[0] = NULL;
+		labelStr[0] = 0;
 		(*insPoint) = 0;
 		return;
 	}
 	place += m_iStartValue;
- 
+
 	//	if (depth == 0 )
 	if(IS_NUMBERED_LIST_TYPE(m_List_Type))
 	{
@@ -422,9 +434,8 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 			labelStr[(*insPoint)++] = CONV_TO_UCS leftDelim[i];
 		}
 	}
-		
 	switch( m_List_Type)
-	{ 
+	{
 	case NUMBERED_LIST:
 		sprintf(p,"%i",place);
 		psz = UT_XML_strlen( p);
@@ -469,7 +480,7 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 			labelStr[(*insPoint)++] =  CONV_TO_UCS p[i];
 		}
 		break;
-#ifdef BIDI_ENABLED
+
 	case ARABICNUMBERED_LIST:
 		sprintf(p,"%i",place);
 		psz = UT_XML_strlen( p);
@@ -478,10 +489,11 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 			labelStr[(*insPoint)++] =  (CONV_TO_UCS p[i]) + 0x0660 - (CONV_TO_UCS '0');
 		}
 		break;
+
 	case HEBREW_LIST:
 		dec2hebrew(labelStr,insPoint,place);
 		break;
-#endif
+
 	case BULLETED_LIST:
 		labelStr[(*insPoint)++] =  CONV_TO_UCS 0xb7; // was UCS_BULLET;
 		break;
@@ -531,7 +543,7 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 		break;
 	}
 	
-	if( m_List_Type < BULLETED_LIST && 
+	if( m_List_Type < BULLETED_LIST &&
 	    (UT_XML_strnicmp(m_pszDecimal,rightDelim,4) != 0 || depth == 0) )
 	{
 		psz = UT_XML_strlen(rightDelim);
@@ -540,7 +552,7 @@ void    fl_AutoNum::_getLabelstr( UT_UCSChar labelStr[], UT_uint32 * insPoint,
 			labelStr[(*insPoint)++] =  CONV_TO_UCS rightDelim[i];
 		}
 	}
-	labelStr[(*insPoint)] = NULL;
+	labelStr[(*insPoint)] = 0;
 	return;
 }
 
@@ -553,11 +565,11 @@ const UT_UCSChar * fl_AutoNum::getLabel(PL_StruxDocHandle pItem)  const
 	_getLabelstr( label, &insPoint, depth , pItem);
 	if(insPoint == 0 )
 	{
-		return (const UT_UCSChar *) NULL;
+		return static_cast<const UT_UCSChar *>(NULL);
 	}
 	else
 	{
-		return (const UT_UCSChar *) label;
+		return static_cast<const UT_UCSChar *>(label);
 	}
 }
 
@@ -616,7 +628,7 @@ void fl_AutoNum::setStartValue(UT_uint32 start)
 
 void fl_AutoNum::setAsciiOffset(UT_uint32 new_asciioffset)
 {
-	m_iAsciiOffset = (UT_uint16) new_asciioffset;
+	m_iAsciiOffset = static_cast<UT_uint16>(new_asciioffset);
 	m_bDirty = true;
 }
 
@@ -627,12 +639,12 @@ UT_uint32 fl_AutoNum::getStartValue32() const
 
 void fl_AutoNum::insertFirstItem(PL_StruxDocHandle pItem, PL_StruxDocHandle pLast, UT_uint32 depth, bool bDoFix)
 {
-	UT_sint32 i = -1; 
+	UT_sint32 i = -1;
 	if(m_pItems.getItemCount() > 0)
-		i = m_pItems.findItem((void *) pItem);
+		i = m_pItems.findItem(const_cast<void *>(pItem));
 	if(i < 0)
 	{
-		m_pItems.insertItemAt((void *) pItem, 0);
+		m_pItems.insertItemAt(const_cast<void *>(pItem), 0);
 		m_bDirty = true;
 	}
 	if(bDoFix)
@@ -664,12 +676,12 @@ void fl_AutoNum::insertItem(PL_StruxDocHandle pItem, PL_StruxDocHandle pPrev, bo
 {
 	UT_sint32 ndx,i;
 	UT_ASSERT(pItem);
-	ndx = m_pItems.findItem((void *) pItem);
+	ndx = m_pItems.findItem(const_cast<void *>(pItem));
 	if(ndx >= 0)
 		return;
 	m_bDirty = true;
-	ndx = m_pItems.findItem((void *) pPrev) + 1;
-	m_pItems.insertItemAt((void *) pItem, ndx);
+	ndx = m_pItems.findItem(const_cast<void *>(pPrev)) + 1;
+	m_pItems.insertItemAt(const_cast<void *>(pItem), ndx);
 	if(bDoFix)
 	{
 		fixListOrder();
@@ -678,7 +690,7 @@ void fl_AutoNum::insertItem(PL_StruxDocHandle pItem, PL_StruxDocHandle pPrev, bo
 		return;
 
 	// scan through all the lists and update parent pointers
-        
+
 	UT_sint32 numlists = m_pDoc->getListsCount();
 	for(i=0; i<numlists; i++)
 	{
@@ -701,16 +713,16 @@ void fl_AutoNum::prependItem(PL_StruxDocHandle pItem, PL_StruxDocHandle pNext, b
 	UT_sint32 i;
 	UT_ASSERT(pItem);
 	PL_StruxDocHandle pPrev = NULL;
-	ndx = m_pItems.findItem((void *) pItem);
+	ndx = m_pItems.findItem(const_cast<void *>(pItem));
 	if(ndx >= 0)
 		return;
 	m_bDirty = true;
-	ndx = m_pItems.findItem((void *) pNext);
+	ndx = m_pItems.findItem(const_cast<void *>(pNext));
 	if(ndx > 0)
 	{
 		pPrev = m_pItems.getNthItem(ndx-1);
 	}
-	m_pItems.insertItemAt((void *) pItem, ndx);
+	m_pItems.insertItemAt(const_cast<void *>(pItem), ndx);
 	if(bDoFix)
 		fixListOrder(); // safety!!
 	if(m_pDoc->areListUpdatesAllowed() == false)
@@ -718,7 +730,7 @@ void fl_AutoNum::prependItem(PL_StruxDocHandle pItem, PL_StruxDocHandle pNext, b
 	if(pPrev != NULL)
 	{
 		// scan through all the lists and update parent pointers
-        
+
 		UT_sint32 numlists = m_pDoc->getListsCount();
 		for(i=0; i<numlists; i++)
 		{
@@ -736,11 +748,11 @@ void fl_AutoNum::prependItem(PL_StruxDocHandle pItem, PL_StruxDocHandle pNext, b
 
 void fl_AutoNum::removeItem(PL_StruxDocHandle pItem)
 {
-	UT_sint32 ndx = m_pItems.findItem((void *)pItem);
+	UT_sint32 ndx = m_pItems.findItem(const_cast<void *>(pItem));
 	UT_sint32 i;
 	//
 	// For multi-views we might have already deleted pItem from the
-	// fl_AutoNum 
+	// fl_AutoNum
 	//
 	//
 	UT_ASSERT(ndx != -1);
@@ -749,17 +761,17 @@ void fl_AutoNum::removeItem(PL_StruxDocHandle pItem)
 		m_bDirty = true;
 		_updateItems(0,NULL);
 		return;
-	}        
+	}
 	PL_StruxDocHandle ppItem = NULL;
 	if(ndx > 0)
 	{
-		ppItem =  ( PL_StruxDocHandle) m_pItems.getNthItem(ndx - 1);
+		ppItem =  static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(ndx - 1));
 	}
 	m_pItems.deleteNthItem(ndx);
 	m_bDirty = true;
 
 	// scan through all the lists and update parent pointers
-	
+
 	UT_sint32 numlists = m_pDoc->getListsCount();
 	for(i=0; i<numlists; i++)
 	{
@@ -798,20 +810,20 @@ UT_uint32 fl_AutoNum::getNumLabels() const
 UT_sint32 fl_AutoNum::getPositionInList(PL_StruxDocHandle pItem, UT_uint32 depth) const
 {
 	UT_ASSERT(m_pItems.getItemCount() > 0);
-	
+
 	PL_StruxDocHandle pTmp;
 	UT_uint32 ndx = 0;
 	UT_uint32 count = m_pItems.getItemCount();
 	bool bOnLevel = true;
 	bool bFirstItem = false;
-	
+
 	for (UT_uint32 i = 0; i < count; i++)
 	{
-		pTmp = (PL_StruxDocHandle) m_pItems.getNthItem(i);
+		pTmp = static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(i));
 		//		bOnLevel = (depth == 0);
 		const fl_AutoNum* pAuto = getAutoNumFromSdh(pItem);
-		bOnLevel = (bool)( pAuto == this);
-		bFirstItem = (bool)(pTmp == m_pItems.getFirstItem());
+		bOnLevel = static_cast<bool>( pAuto == this);
+		bFirstItem = static_cast<bool>(pTmp == m_pItems.getFirstItem());
 		if (pTmp == pItem)
 		{
 			if (m_bWordMultiStyle && !bOnLevel && !bFirstItem)
@@ -823,7 +835,7 @@ UT_sint32 fl_AutoNum::getPositionInList(PL_StruxDocHandle pItem, UT_uint32 depth
 			ndx++;
 		}
 	}
-	
+
 	return -1;
 	// return m_pItems.findItem(pItem);
 }
@@ -836,7 +848,7 @@ fl_AutoNum * fl_AutoNum::getAutoNumFromSdh(PL_StruxDocHandle sdh)
 	{
 		if(isItem(sdh) == false)
 		{
-			return (fl_AutoNum *) NULL;
+			return static_cast<fl_AutoNum *>(NULL);
 		}
 		return this;
 	}
@@ -849,7 +861,7 @@ fl_AutoNum * fl_AutoNum::getAutoNumFromSdh(PL_StruxDocHandle sdh)
 	}
 	if(i>= numLists)
 	{
-		return (fl_AutoNum * ) NULL;
+		return static_cast<fl_AutoNum *>(NULL);
 	}
 	return pAuto;
 }
@@ -883,13 +895,13 @@ const fl_AutoNum* fl_AutoNum::getAutoNumFromSdh(PL_StruxDocHandle sdh) const
 
 const bool fl_AutoNum::isItem(PL_StruxDocHandle pItem) const
 {
-	if (m_pItems.findItem((void *)(pItem)) == -1)
+	if (m_pItems.findItem(const_cast<void *>(pItem)) == -1)
 		return false;
 	else
 		return true;
 }
 
-const bool fl_AutoNum::isEmpty() 
+const bool fl_AutoNum::isEmpty()
 {
 	if (m_pItems.getItemCount() > 0)
 		return false;
@@ -897,7 +909,7 @@ const bool fl_AutoNum::isEmpty()
 		return true;
 }
 
-PL_StruxDocHandle fl_AutoNum::getFirstItem()
+PL_StruxDocHandle fl_AutoNum::getFirstItem() const
 {
 	return (PL_StruxDocHandle)
 		(m_pItems.getItemCount() ? m_pItems.getFirstItem() : 0);
@@ -911,7 +923,7 @@ PL_StruxDocHandle fl_AutoNum::getLastItem()
 		return NULL;
 	else
 	{
-		return (PL_StruxDocHandle) m_pItems.getNthItem(i-1);
+		return static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(i-1));
 	}
 }
 
@@ -923,7 +935,7 @@ bool fl_AutoNum::doesItemHaveLabel( fl_BlockLayout * pItem)
 	{
 		if(pRun->getType() == FPRUN_FIELD)
 		{
-			fp_FieldRun * pFRun = (fp_FieldRun *) pRun;
+			fp_FieldRun * pFRun = static_cast<fp_FieldRun *>(pRun);
 			if(pFRun->getFieldType() == FPFIELD_list_label)
 			{
 				bStop = true;
@@ -941,18 +953,18 @@ bool fl_AutoNum::doesItemHaveLabel( fl_BlockLayout * pItem)
 }
 
 
-bool fl_AutoNum::isLastOnLevel(PL_StruxDocHandle pItem) 
+bool fl_AutoNum::isLastOnLevel(PL_StruxDocHandle pItem)
 {
-	UT_sint32 itemloc = m_pItems.findItem((void *) pItem);
+	UT_sint32 itemloc = m_pItems.findItem(const_cast<void *>(pItem));
 	if (itemloc == -1)
 		return false;
-	if(itemloc == (UT_sint32) (m_pItems.getItemCount() - 1))
+	if(itemloc == static_cast<UT_sint32>(m_pItems.getItemCount() - 1))
 		return true;
 	else
 		return false;
 }
 
-fl_AutoNum * fl_AutoNum::getActiveParent(void) 
+fl_AutoNum * fl_AutoNum::getActiveParent(void)
 {
 	fl_AutoNum * pAutoNum = m_pParent;
 
@@ -989,8 +1001,8 @@ void fl_AutoNum::_setParent(fl_AutoNum * pParent)
 		UT_uint32 i = 0;
 		for(i=0; i < m_pItems.getItemCount() ; i++)
 		{
-			PL_StruxDocHandle sdh = (PL_StruxDocHandle) m_pItems.getNthItem(i);
-			m_pDoc->changeStruxForLists(sdh, (const char * )szParent);
+			PL_StruxDocHandle sdh = static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(i));
+			m_pDoc->changeStruxForLists(sdh, static_cast<const char *>(szParent));
 		}
 	}
 }
@@ -1033,13 +1045,13 @@ void fl_AutoNum::_updateItems(UT_uint32 start, PL_StruxDocHandle notMe)
 		for (UT_uint32 i = start; i < m_pItems.getItemCount(); i++)
 		{
 			//       	 	UT_DEBUGMSG(("Entering _updateItems for loop\n"));
-			PL_StruxDocHandle pTmp = (PL_StruxDocHandle) m_pItems.getNthItem(i);
+			PL_StruxDocHandle pTmp = static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(i));
 			UT_ASSERT(pTmp);
 			m_pDoc->listUpdate(pTmp);
-			
+
 			// scan through all the lists and update child lists if connected to this item
-	
-			PL_StruxDocHandle pItem =  (PL_StruxDocHandle) m_pItems.getNthItem(i);  
+
+			PL_StruxDocHandle pItem = static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(i));
 			for(j=0; j<numlists; j++)
 			{
 				fl_AutoNum * pAuto = m_pDoc->getNthList(j);
@@ -1066,12 +1078,12 @@ bool fl_AutoNum::isContainedByList(PL_StruxDocHandle pItem)
 	UT_uint32 no_items = m_pItems.getItemCount();
 	if(no_items == 0)
 		return false;
-	sdh = ( PL_StruxDocHandle) m_pItems.getFirstItem();
+	sdh = static_cast<PL_StruxDocHandle>(m_pItems.getFirstItem());
 	bret = m_pDoc->getPrevStruxOfType(sdh,PTX_Block, &sdh_prev);
 	if(bret == false)
 		sdh_prev = sdh;
 	pos_prev = m_pDoc->getStruxPosition(sdh_prev);
-	sdh = ( PL_StruxDocHandle) m_pItems.getNthItem(no_items-1);
+	sdh = static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(no_items-1));
 	bret = m_pDoc->getNextStruxOfType(sdh,PTX_Block, &sdh_next);
 	if(bret == false)
 		sdh_next = sdh;
@@ -1086,17 +1098,17 @@ bool fl_AutoNum::isContainedByList(PL_StruxDocHandle pItem)
 PL_StruxDocHandle fl_AutoNum::getNthBlock( UT_uint32 list_num)
 {
 	if(list_num <0 || list_num >= m_pItems.getItemCount())
-		return (PL_StruxDocHandle) NULL;
+		return static_cast<PL_StruxDocHandle>(NULL);
 	else
-		return (PL_StruxDocHandle) m_pItems.getNthItem(list_num);
+		return static_cast<PL_StruxDocHandle>(m_pItems.getNthItem(list_num));
 }
 
 PL_StruxDocHandle fl_AutoNum::getPrevInList( PL_StruxDocHandle pItem)
 {
-	UT_sint32 itemloc = m_pItems.findItem((void *) pItem);
+	UT_sint32 itemloc = m_pItems.findItem(const_cast<void *>(pItem));
 	if (itemloc == -1 || itemloc == 0)
 		return NULL;
-	return (PL_StruxDocHandle) m_pItems.getNthItem( (UT_uint32) itemloc - 1);
+	return static_cast<PL_StruxDocHandle>(m_pItems.getNthItem( static_cast<UT_uint32>(itemloc) - 1));
 }
 
 inline UT_uint32 fl_AutoNum::_getLevelValue(fl_AutoNum * pAutoNum)
@@ -1192,16 +1204,16 @@ char *  fl_AutoNum::dec2roman(UT_sint32 value, bool lower)
 
 	char * rmn = UT_strdup (roman.c_str());
 
-	if (lower == true) 
+	if (lower == true)
 	{
 		int len;
 		len = roman.size();
-		while (--len >= 0) 
+		while (--len >= 0)
 		{
-			UT_sint32 r = (UT_sint32) roman[len];
+			UT_sint32 r = static_cast<UT_sint32>(roman[len]);
 			if( (r >= (UT_sint32) 'A') && (r <= (UT_sint32) 'Z'))
 				r = r + 32;
-			rmn[len] = (char) r;
+			rmn[len] = static_cast<char>(r);
 		}
 	}
 
@@ -1212,24 +1224,24 @@ char * fl_AutoNum::dec2ascii(UT_sint32 value, UT_uint32 offset)
 {
 	char ascii[30];
 	UT_uint32 ndx, count, i;
-	
+
 	ascii[0] = '\0';
 	ndx = abs(value % 26);
 	count = abs(value / 26);
-	
+
 	// For now, we do this like Word. A preference would be nice.
 	for (i = 0; i <= count; i++)
 	{
-		ascii[i] = (char)(ndx + offset);
+		ascii[i] = static_cast<char>(ndx + offset);
 	}
 	ascii[i] = '\0';
-	
+
 	return UT_strdup(ascii);
 }
-#ifdef BIDI_ENABLED
+
 void fl_AutoNum::dec2hebrew(UT_UCSChar labelStr[], UT_uint32 * insPoint, UT_sint32 value)
 {
-	UT_UCSChar gHebrewDigit[22] = 
+	UT_UCSChar gHebrewDigit[22] =
 	{
 		//   1       2       3       4       5       6       7       8       9
 		0x05D0, 0x05D1, 0x05D2, 0x05D3, 0x05D4, 0x05D5, 0x05D6, 0x05D7, 0x05D8,
@@ -1271,7 +1283,7 @@ void fl_AutoNum::dec2hebrew(UT_UCSChar labelStr[], UT_uint32 * insPoint, UT_sint
 				// 15 is represented by 9 and 6, not 10 and 5
 				// 16 is represented by 9 and 7, not 10 and 6
 				n2 = 9;
-				digit = gHebrewDigit[ n2 - 1];    
+				digit = gHebrewDigit[ n2 - 1];
 			} else {
 				n2 = n3 - (n3 % 10);
 				digit = gHebrewDigit[(n2/10)-1+9];
@@ -1280,8 +1292,8 @@ void fl_AutoNum::dec2hebrew(UT_UCSChar labelStr[], UT_uint32 * insPoint, UT_sint
 			n3 -= n2;
 			labelStr[(*insPoint)++] = digit;
 		} // if
-  
-		// Process digit for 1 - 9 
+
+		// Process digit for 1 - 9
 		if ( n3 > 0)
 		{
 			labelStr[(*insPoint)++] = gHebrewDigit[n3-1];
@@ -1289,37 +1301,44 @@ void fl_AutoNum::dec2hebrew(UT_UCSChar labelStr[], UT_uint32 * insPoint, UT_sint
 		value /= 1000;
 	} while (value >= 1);
 }
-#endif
-const char ** fl_AutoNum::getAttributes(void) 
+
+
+const char ** fl_AutoNum::getAttributes(void)
 {
 	static char  szID[15], szPid[15], szType[5], szStart[5];
 	UT_Vector va;
- 
+
 	sprintf(szID, "%i", m_iID);
-	va.addItem( (void *) "id"); va.addItem( (void *) szID);
-        
+	va.addItem( static_cast<const void *>("id"));
+	va.addItem( static_cast<void *>(szID));
+
 	if (m_pParent)
 		sprintf(szPid, "%i", m_pParent->getID());
 	else
 		sprintf(szPid, "0");
-	va.addItem( (void *) "parentid"); va.addItem( (void *) szPid);
-                
+	va.addItem( static_cast<const void *>("parentid"));
+	va.addItem( static_cast<void *>(szPid));
+
 	sprintf(szType, "%i", m_List_Type);
-	va.addItem( (void *) "type"); va.addItem(szType);
-        
+	va.addItem( static_cast<const void *>("type"));
+	va.addItem( static_cast<void *>(szType));
+
 	sprintf(szStart, "%i", m_iStartValue);
-	va.addItem( (void *) "start-value"); va.addItem(szStart);
-	
-	va.addItem( (void *) "list-delim"); va.addItem( (void *) m_pszDelim);
-	
-	va.addItem( (void *) "list-decimal"); va.addItem( (void *) m_pszDecimal);
-	
+	va.addItem( static_cast<const void *>("start-value"));
+	va.addItem( static_cast<void *>(szStart));
+
+	va.addItem( static_cast<const void *>("list-delim"));
+	va.addItem( static_cast<void *>(m_pszDelim));
+
+	va.addItem( static_cast<const void *>("list-decimal"));
+	va.addItem( static_cast<void *>(m_pszDecimal));
+
 	UT_uint32 counta = va.getItemCount() + 1;
 	UT_uint32 i;
-	const char ** attribs = (const char **) UT_calloc(counta, sizeof(char *));
+	const char ** attribs = static_cast<const char **>(UT_calloc(counta, sizeof(char *)));
 	for (i = 0; i < va.getItemCount(); i++)
 	{
-		attribs[i] = (const char *) va[i];
+		attribs[i] = static_cast<const char *>(va[i]);
 	}
 	return attribs;
 }
