@@ -118,8 +118,8 @@ public:
 	void                drawLines(fp_TableContainer * pBroke);
 	void                drawLinesAdjacent(void);
 	void                draw(fp_Line * pLine);
-	fp_TableContainer * getBrokenTable(fp_Line * pLine);
-	fp_Column *         getColumn(fp_Line *pLine);
+	fp_TableContainer * getBrokenTable(fp_Container * pCon);
+	fp_Column *         getColumn(fp_Container *pCon);
 	UT_sint32           tweakBrokenTable(fp_TableContainer * pBroke);
 	virtual void		draw(dg_DrawArgs*);
 	virtual void		draw(GR_Graphics*) {}
@@ -228,6 +228,7 @@ public:
 	bool                isDirty(void) const
 	    {  return m_bDirty;}
 	bool                doesIntersectClip(fp_TableContainer * pBroke, UT_Rect * rClip);
+	bool                isInNestedTable(void);
 #ifdef FMT_TEST
 	void				__dump(FILE * fp) const;
 #endif
@@ -336,7 +337,7 @@ public:
     virtual void        mapXYToPosition(UT_sint32 x, UT_sint32 y, 
 										PT_DocPosition& pos,
 										bool& bBOL, bool& bEOL);
-
+	virtual fp_Page *   getPage(void);
 	void				layout(void);
 	virtual void        setY(UT_sint32 iY);
 	virtual UT_sint32   getHeight(void);
