@@ -320,9 +320,8 @@ public:
 	void			cmdCharDelete(bool bForward, UT_uint32 count);
 	void			delTo(FV_DocPos dp);
 	UT_UCSChar *	getSelectionText(void);
-#if 0
+
 	UT_UCSChar *	getTextBetweenPos(PT_DocPosition pos1, PT_DocPosition pos2);
-#endif
 	inline PT_DocPosition  getInsPoint () const { return m_iInsPoint; }
 	void			warpInsPtToXY(UT_sint32 xPos, UT_sint32 yPos, bool bClick);
 	void			moveInsPtTo(FV_DocPos dp, bool bClearSelection = true);
@@ -471,6 +470,7 @@ public:
 
 	bool				insertPageNum(const XML_Char ** props, HdrFtrType hfType);
 	void				setPoint(PT_DocPosition pt);
+	void                ensureInsertionPointOnScreen(void);
 
 // -----------------------
 	void                killBlink(void);
