@@ -82,7 +82,7 @@ void signalWrapper(int sig_num);
 #include <TranslationUtils.h>
 #include <DataIO.h>
 
-#define SPLASH_UP_TIME	5				// seconds
+#define SPLASH_UP_TIME	1				// seconds
 
 extern unsigned char g_pngSplash[];             // see ap_wp_Splash.cpp
 extern unsigned long g_pngSplash_sizeof;        // see ap_wp_Splash.cpp
@@ -98,6 +98,9 @@ class SplashWin:public BWindow {
 
 SplashWin::SplashWin(BMessage *data)
           :BWindow(data) {
+	BScreen* screen;
+	screen = new BScreen(B_MAIN_SCREEN_ID);
+
 	BView *view = FindView("splashView");
 	if (view) {
 		BMemoryIO memio(g_pngSplash, g_pngSplash_sizeof);
@@ -108,7 +111,11 @@ SplashWin::SplashWin(BMessage *data)
 			UT_DEBUGMSG(("Could not interpret splash image...\n"));
 
 		view->Sync();
-        }                                     
+        }
+     BRect wrect, srect;
+     srect = screen->Frame();
+     wrect = Bounds();
+	MoveTo((srect.right - (wrect.right - wrect.left)) / 2, (srect.bottom - (wrect.bottom - wrect.top)) / 2);
 	Show();
 	ignore = SPLASH_UP_TIME;			// keep on screen n seconds
 	SetPulseRate(1000000);				// a 1 second pulse
@@ -423,7 +430,7 @@ const XAP_StringSet * AP_BeOSApp::getStringSet(void) const
 //////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////
 
-void AP_BeOSApp::copyToClipboard(PD_DocumentRange * pDocRange)
+void AP_BeOSApp::copyToClipboard(PD_DocumentRange * pDocRange, bool bUseClipboard)
 {
 	// copy the given subset of the given document to the
 	// system clipboard in a variety of formats.
@@ -471,7 +478,7 @@ void AP_BeOSApp::pasteFromClipboard(PD_DocumentRange * pDocRange, bool, bool bHo
 		UT_uint32 iLen = 0;
 		bool bResult = m_pClipboard->getClipboardData(AP_CLIPBOARD_RTF,(void**)&pData,&iLen);
 		UT_ASSERT(bResult);
-		iLen = MyMin(iLen,strlen((const char *) pData));
+		iLen = UT_MIN(iLen,strlen((const char *) pData));
 		UT_DEBUGMSG(("PasteFromClipboard: pasting %d bytes in RTF format.\n",iLen));
 		IE_Imp_RTF * pImpRTF = new IE_Imp_RTF(pDocRange->m_pDoc);
 		pImpRTF->pasteFromBuffer(pDocRange,pData,iLen);
@@ -485,7 +492,7 @@ void AP_BeOSApp::pasteFromClipboard(PD_DocumentRange * pDocRange, bool, bool bHo
 		UT_uint32 iLen = 0;
 		bool bResult = m_pClipboard->getClipboardData(AP_CLIPBOARD_TEXTPLAIN_8BIT,(void**)&pData,&iLen);
 		UT_ASSERT(bResult);
-		iLen = MyMin(iLen,strlen((const char *) pData));
+		iLen = UT_MIN(iLen,strlen((const char *) pData));
 		UT_DEBUGMSG(("PasteFromClipboard: pasting %d bytes in TEXTPLAIN format.\n",iLen));
 		IE_Imp_Text * pImpText = new IE_Imp_Text(pDocRange->m_pDoc);
 		pImpText->pasteFromBuffer(pDocRange,pData,iLen);
