@@ -20,7 +20,8 @@
 #include "ut_assert.h"
 #include "xap_App.h"
 #include "xap_QNXApp.h"
-#include "xap_QNXFrame.h"
+#include "xap_QNXFrameImpl.h"
+#include "xap_Frame.h"
 #include "ap_Strings.h"
 
 #include "ap_QNXDialog_PageSetup.h"
@@ -55,42 +56,6 @@ static bool label_with_pixmap(PtWidget_t *widget, const char **pIconData, UT_uin
 	return true;
 }
 
-static char *
-_ev_convert (char * bufResult,
-	     const char * szString)
-{
-	UT_ASSERT (szString && bufResult);
-	
-	char *pl = bufResult;
-	char *s = (char *)szString;
-
-	int len = strlen (szString);
-	int i;
-
-	for (i = 0; i < len; i++)
-	  {
-	    if (*s == '&')
-	      s++;
-	    else
-	      *pl++ = *s++;
-	  }
-
-	*pl = 0;
-	return bufResult;
-}
-
-/*********************************************************************************/
-
-// some static variables
-/*
-static fp_PageSize::Predefined last_page_size = fp_PageSize::Custom;
-*/
-
-/*********************************************************************************/
-
-// a *huge* convenience macro
-static char _ev_buf[256];
-#define _(a, x) _ev_convert (_ev_buf, pSS->getValue (a##_STRING_ID_##x))
 
 /*********************************************************************************/
 
@@ -142,17 +107,6 @@ static int s_page_units_changed (PtWidget_t * w, void *data, PtCallbackInfo_t *i
 	return Pt_CONTINUE;
 }
 
-static int s_margin_units_changed (PtWidget_t * w, void *data, PtCallbackInfo_t *info)
-{
-	AP_QNXDialog_PageSetup *dlg = (AP_QNXDialog_PageSetup *)data;
-	UT_ASSERT(w && dlg);
-	if (info->reason_subtype != Pt_LIST_SELECTION_FINAL) {
-		return Pt_CONTINUE;
-	}
-	dlg->event_MarginUnitsChanged ();
-	return Pt_CONTINUE;
-}
-
 /*********************************************************************************/
 
 void AP_QNXDialog_PageSetup::event_OK (void)
@@ -229,7 +183,7 @@ void AP_QNXDialog_PageSetup::event_PageUnitsChanged (void)
 	fp_PageSize::Predefined pd = (fp_PageSize::Predefined)((int)m_vecsize.getNthItem(index - 1));
 	fp_PageSize ps(pd);
 
-  	double *d, width, height;
+  	double width, height;
   
 	// get values
 	width  = (double)ps.Width(pu);
@@ -328,15 +282,12 @@ AP_QNXDialog_PageSetup::~AP_QNXDialog_PageSetup (void)
 
 void AP_QNXDialog_PageSetup::runModal (XAP_Frame *pFrame)
 {
-	// To center the dialog, we need the frame of its parent.
-    XAP_QNXFrame * pQNXFrame = static_cast<XAP_QNXFrame *>(pFrame);
-    UT_ASSERT(pQNXFrame);
-    
-    // Get the GtkWindow of the parent frame
-    PtWidget_t * parentWindow = pQNXFrame->getTopLevelWindow();
-    UT_ASSERT(parentWindow);
-	PtSetParentWidget(parentWindow);
-   
+  	XAP_QNXFrameImpl * pQNXFrameImpl = (XAP_QNXFrameImpl*)pFrame->getFrameImpl();
+	PtWidget_t *parentWindow =	pQNXFrameImpl->getTopLevelWindow();	
+	UT_ASSERT(parentWindow);
+
+	PtSetParentWidget(parentWindow); 
+
     // Build the window's widgets and arrange them
     PtWidget_t * mainWindow = _constructWindow();
     UT_ASSERT(mainWindow);
@@ -371,15 +322,15 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 	PtWidget_t *hgroup;
 	PtWidget_t *vgroup;
 	PtWidget_t *vgroup2;
-	PtWidget_t *hgroup2;
-
 
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_TITLE, _(AP, DLG_PageSetup_Title), 0);
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_RENDER_FLAGS, 0, ABI_MODAL_WINDOW_RENDER_FLAGS);
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_MANAGED_FLAGS, 0, ABI_MODAL_WINDOW_MANAGE_FLAGS);
 	m_window = PtCreateWidget(PtWindow, NULL, n, args);
-		PtAddCallback(m_window,Pt_CB_WINDOW_CLOSING,s_delete_clicked,this);
+	SetupContextHelp(m_window,this);
+	PtAddHotkeyHandler(m_window,Pk_F1,0,Pt_HOTKEY_SYM,this,OpenHelp);
+	PtAddCallback(m_window,Pt_CB_WINDOW_CLOSING,s_delete_clicked,this);
 
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_GROUP_ORIENTATION, Pt_GROUP_VERTICAL, 0);
@@ -388,57 +339,47 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 	PtSetArg(&args[n++], Pt_ARG_GROUP_SPACING_Y, 10, 0);
 	vgroup = PtCreateWidget(PtGroup, m_window, n, args);
 
-#define TAB_WIDTH 400
-#define TAB_HEIGHT 300
 #define _ANCHOR (Pt_LEFT_ANCHORED_LEFT | Pt_RIGHT_ANCHORED_RIGHT)
 	memset(&zero, 0, sizeof(0));
 
 	/*** Create the tabbed group ***/	
 	n = 0;
-    PtSetArg(&args[n++], Pt_ARG_WIDTH, TAB_WIDTH, 0);
-    PtSetArg(&args[n++], Pt_ARG_HEIGHT, TAB_HEIGHT, 0);
+	PtSetArg(&args[n++], Pt_ARG_RESIZE_FLAGS,Pt_TRUE,Pt_RESIZE_XY_AS_REQUIRED);
 	PtWidget_t *panelgroup = PtCreateWidget(PtPanelGroup, vgroup, n, args);
 
 	/* Create the first tab (Page) */
 	n = 0;
-    PtSetArg(&args[n++], Pt_ARG_TITLE, _(AP, DLG_PageSetup_Page), 0);
+  PtSetArg(&args[n++], Pt_ARG_TITLE, _(AP, DLG_PageSetup_Page), 0);
+	PtSetArg(&args[n++], Pt_ARG_RESIZE_FLAGS,Pt_TRUE,Pt_RESIZE_XY_AS_REQUIRED);
 	PtWidget_t *panel = PtCreateWidget(PtPane, panelgroup, n, args);
 
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_GROUP_ORIENTATION, Pt_GROUP_VERTICAL, 0);
-	PtSetArg(&args[n++], Pt_ARG_GROUP_FLAGS, Pt_GROUP_STRETCH_VERTICAL, Pt_GROUP_STRETCH_VERTICAL);
-	PtSetArg(&args[n++], Pt_ARG_RESIZE_FLAGS, Pt_RESIZE_XY_AS_REQUIRED, 
-											  Pt_RESIZE_XY_AS_REQUIRED | Pt_RESIZE_XY_ALWAYS);
-	PtSetArg(&args[n++], Pt_ARG_ANCHOR_OFFSETS, &zero, 0);
-	PtSetArg(&args[n++], Pt_ARG_ANCHOR_FLAGS, _ANCHOR, _ANCHOR);
+	PtSetArg(&args[n++], Pt_ARG_GROUP_FLAGS, Pt_TRUE, Pt_GROUP_EQUAL_SIZE_HORIZONTAL);
+	PtSetArg(&args[n++], Pt_ARG_GROUP_ROWS_COLS,3,0);
 	PtWidget_t *vpanel = PtCreateWidget(PtGroup, panel, n, args);
 
 	/** Paper Section **/
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_ANCHOR_OFFSETS, &zero, 0);
-	PtSetArg(&args[n++], Pt_ARG_ANCHOR_FLAGS, _ANCHOR, _ANCHOR);
+	PtSetArg(&args[n++], Pt_ARG_GROUP_ORIENTATION,Pt_GROUP_VERTICAL,0);
+	PtSetArg(&args[n++], Pt_ARG_GROUP_ROWS_COLS,3,0);
 	hgroup = PtCreateWidget(PtGroup, vpanel, n, args);
 	pretty_group(hgroup, _(AP, DLG_PageSetup_Paper));
 
 	/* First column: padding, paper size */
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_GROUP_ORIENTATION, Pt_GROUP_VERTICAL, 0);
-	vgroup2 = PtCreateWidget(PtGroup, hgroup, n, args);
-	n = 0;
-	PtCreateWidget(PtLabel, vgroup2, n, args);
+	PtCreateWidget(PtLabel, hgroup, n, args);
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP, DLG_PageSetup_Paper_Size), 0);
-	PtCreateWidget(PtLabel, vgroup2, n, args);
-
-	/* Second column: padding, paper combo */
-	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_GROUP_ORIENTATION, Pt_GROUP_VERTICAL, 0);
-	vgroup2 = PtCreateWidget(PtGroup, hgroup, n, args);
-	n = 0;
-	PtCreateWidget(PtLabel, vgroup2, n, args);
-	n = 0;
+	PtCreateWidget(PtLabel, Pt_DEFAULT_PARENT, n, args);
+	n=0;
+	PtCreateWidget(PtLabel,Pt_DEFAULT_PARENT,n,args);
+	PtCreateWidget(PtLabel,Pt_DEFAULT_PARENT,n,args); //Padding
+	n=0;
+	
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
-	m_optionPageSize = PtCreateWidget(PtComboBox, vgroup2, n, args);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_FLAGS,Pt_FALSE,Pt_EDITABLE);
+	m_optionPageSize = PtCreateWidget(PtComboBox, Pt_DEFAULT_PARENT, n, args);
 	for (int i = (int)fp_PageSize::_first_predefined_pagesize_;
 		 i < (int)fp_PageSize::_last_predefined_pagesize_dont_use_; i++)
     {
@@ -450,16 +391,23 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 	UT_QNXComboSetPos(m_optionPageSize, current + 1);
 	PtAddCallback(m_optionPageSize, Pt_CB_SELECTION, s_page_size_changed, this);
 
+	n=0;
+	PtCreateWidget(PtLabel,Pt_DEFAULT_PARENT,n,args); //Padding
+
 	/* Third column: Width, Height, Units */
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_GROUP_ROWS_COLS, 2, 0);
-	PtSetArg(&args[n++], Pt_ARG_GROUP_FLAGS, Pt_GROUP_EQUAL_SIZE_HORIZONTAL | Pt_GROUP_EQUAL_SIZE_VERTICAL,
-											 Pt_GROUP_EQUAL_SIZE_HORIZONTAL | Pt_GROUP_EQUAL_SIZE_VERTICAL);
-	hgroup2 = PtCreateWidget(PtGroup, hgroup, n, args);
-	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP, DLG_PageSetup_Width), 0);
-	PtCreateWidget(PtLabel, hgroup2, n, args);
+	PtCreateWidget(PtLabel, Pt_DEFAULT_PARENT, n, args);
 	n = 0;
+
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP, DLG_PageSetup_Height), 0);
+	PtCreateWidget(PtLabel, Pt_DEFAULT_PARENT, n, args);
+	n = 0;
+
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP, DLG_PageSetup_Units), 0);
+	PtCreateWidget(PtLabel, Pt_DEFAULT_PARENT, n, args);
+	n = 0;
+
 	d = getPageSize().Width (getPageUnits ());
 	PtSetArg(&args[n++], Pt_ARG_NUMERIC_VALUE, &d, 0);
 	min = 0;
@@ -467,12 +415,10 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 	max = 100;
 	PtSetArg(&args[n++], Pt_ARG_NUMERIC_MAX, &max, 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH / 2, 0);
-	m_entryPageWidth = PtCreateWidget(PtNumericFloat, hgroup2, n, args);
+	m_entryPageWidth = PtCreateWidget(PtNumericFloat, Pt_DEFAULT_PARENT, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP, DLG_PageSetup_Height), 0);
-	PtCreateWidget(PtLabel, hgroup2, n, args);
-	n = 0;
+
 	d = getPageSize().Height (getPageUnits ());
 	PtSetArg(&args[n++], Pt_ARG_NUMERIC_VALUE, &d, 0);
 	min = 0;
@@ -480,14 +426,13 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 	max = 100;
 	PtSetArg(&args[n++], Pt_ARG_NUMERIC_MAX, &max, 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH / 2, 0);
-	m_entryPageHeight = PtCreateWidget(PtNumericFloat, hgroup2, n, args);
+	m_entryPageHeight = PtCreateWidget(PtNumericFloat, Pt_DEFAULT_PARENT, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP, DLG_PageSetup_Units), 0);
-	PtCreateWidget(PtLabel, hgroup2, n, args);
-	n = 0;
+
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
-	m_optionPageUnits = PtCreateWidget(PtComboBox, hgroup2, n, args);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_FLAGS,Pt_FALSE,Pt_EDITABLE);
+	m_optionPageUnits = PtCreateWidget(PtComboBox, Pt_DEFAULT_PARENT, n, args);
 	{
 		const char *itemname;
 		itemname = 	_(XAP, DLG_Unit_inch);
@@ -509,8 +454,6 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 	PtSetArg(&args[n++], Pt_ARG_GROUP_FLAGS, 
 			Pt_GROUP_EQUAL_SIZE_HORIZONTAL | Pt_GROUP_EXCLUSIVE, 
 			Pt_GROUP_EQUAL_SIZE_HORIZONTAL | Pt_GROUP_EXCLUSIVE);
-	PtSetArg(&args[n++], Pt_ARG_ANCHOR_OFFSETS, &zero, 0);
-	PtSetArg(&args[n++], Pt_ARG_ANCHOR_FLAGS, _ANCHOR, _ANCHOR);
 	hgroup = PtCreateWidget(PtGroup, vpanel, n, args);
 	pretty_group(hgroup, _(AP, DLG_PageSetup_Orient));
 
@@ -535,28 +478,27 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 
 	/** Scale Section **/
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_ANCHOR_OFFSETS, &zero, 0);
-	PtSetArg(&args[n++], Pt_ARG_ANCHOR_FLAGS, _ANCHOR, _ANCHOR);
+	PtSetArg(&args[n++],Pt_ARG_GROUP_ROWS_COLS,3,0);
 	hgroup = PtCreateWidget(PtGroup, vpanel, n, args);
 	pretty_group(hgroup, _(AP, DLG_PageSetup_Scale));
 	n = 0;
-	hgroup2 = PtCreateWidget(PtGroup, hgroup, n, args);
-	n = 0;
+	
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(AP, DLG_PageSetup_Adjust), 0);
-	PtCreateWidget(PtLabel, hgroup2, n, args);
+	PtCreateWidget(PtLabel, hgroup, n, args);
 	n = 0;
 	d = getPageScale();
 	PtSetArg(&args[n++], Pt_ARG_NUMERIC_VALUE, &d, 0);
 	PtSetArg(&args[n++], Pt_ARG_NUMERIC_PRECISION, 0, 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
-	m_spinPageScale = PtCreateWidget(PtNumericFloat, hgroup2, n, args);
+	m_spinPageScale = PtCreateWidget(PtNumericFloat, hgroup, n, args);
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,_(AP, DLG_PageSetup_Percent), 0);
-	PtCreateWidget(PtLabel, hgroup2, n, args);
+	PtCreateWidget(PtLabel, hgroup, n, args);
 
 	/*** Second Tab (Margin) ***/
 	n = 0;
-    PtSetArg(&args[n++], Pt_ARG_TITLE, _(AP, DLG_PageSetup_Margin), 0);
+  PtSetArg(&args[n++], Pt_ARG_TITLE, _(AP, DLG_PageSetup_Margin), 0);
+	PtSetArg(&args[n++], Pt_ARG_RESIZE_FLAGS,Pt_TRUE,Pt_RESIZE_XY_AS_REQUIRED);
 	panel = PtCreateWidget(PtPane, panelgroup, n, args);
 
 	n = 0;
@@ -579,6 +521,7 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 	/** Second Row: Units combo, Top/Header spinners */
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_FLAGS,Pt_FALSE,Pt_EDITABLE);
 	m_optionMarginUnits = PtCreateWidget(PtComboBox, hgroup, n, args);
 	{
 		const char *itemname;
@@ -663,10 +606,6 @@ PtWidget_t * AP_QNXDialog_PageSetup::_constructWindow (void)
 	n = 0; 
 	hgroup = PtCreateWidget(PtGroup, vgroup, n, args);
 
-	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_WIDTH, 3* ABI_DEFAULT_BUTTON_WIDTH, 0);
-	PtCreateWidget(PtLabel, hgroup, n, args);
-
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, _(XAP, DLG_OK), 0);	
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
