@@ -453,7 +453,7 @@ PtWidget_t * AP_QNXDialog_Paragraph::_constructWindow(void)
 #define WIN_WIDTH  550	
 #define WIN_HEIGHT 400	
 	n = 0;
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_ParaTitle ).c_str());
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_ParaTitle ).utf8_str());
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_TITLE, unixstr, 0);
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_RENDER_FLAGS, 0, ABI_MODAL_WINDOW_RENDER_FLAGS);
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_MANAGED_FLAGS, 0, ABI_MODAL_WINDOW_MANAGE_FLAGS);
@@ -644,13 +644,13 @@ PtWidget_t * AP_QNXDialog_Paragraph::_constructWindow(void)
 	PtCreateWidget( PtSeparator, NULL, sizeof(args3) / sizeof(PtArg_t), args3 );
 
 	listAlignment = PtCreateWidget( PtComboBox, NULL, sizeof(args4) / sizeof(PtArg_t), args4 );
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_AlignLeft ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_AlignLeft ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listAlignment, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_AlignCentered ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_AlignCentered ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listAlignment, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_AlignRight ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_AlignRight ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listAlignment, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_AlignJustified ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_AlignJustified ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listAlignment, litem, 1, 0); FREEP(unixstr);
 	TFSetDataInt(listAlignment, id_MENU_ALIGNMENT);
 
@@ -674,11 +674,11 @@ PtWidget_t * AP_QNXDialog_Paragraph::_constructWindow(void)
 
 	listSpecial = PtCreateWidget( PtComboBox, NULL, sizeof(args10) / sizeof(PtArg_t), args10 );
 	PtListDeleteAllItems(listSpecial);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpecialNone ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpecialNone ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listSpecial, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpecialFirstLine ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpecialFirstLine ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listSpecial, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpecialHanging ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpecialHanging ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listSpecial, litem, 1, 0); FREEP(unixstr);
 	TFSetDataInt(listSpecial, id_MENU_SPECIAL_INDENT);
 
@@ -717,17 +717,17 @@ PtWidget_t * AP_QNXDialog_Paragraph::_constructWindow(void)
 
 	listLineSpacing = PtCreateWidget( PtComboBox, NULL, sizeof(args21) / sizeof(PtArg_t), args21 );
 	PtListDeleteAllItems(listLineSpacing);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingSingle ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingSingle ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listLineSpacing, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingHalf ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingHalf ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listLineSpacing, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingDouble ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingDouble ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listLineSpacing, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingAtLeast ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingAtLeast ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listLineSpacing, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingExactly ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingExactly ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listLineSpacing, litem, 1, 0); FREEP(unixstr);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingMultiple ).c_str()); litem[0]= unixstr;
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_SpacingMultiple ).utf8_str()); litem[0]= unixstr;
 	PtListAddItems(listLineSpacing, litem, 1, 0); FREEP(unixstr);
 	TFSetDataInt(listLineSpacing, id_MENU_SPECIAL_SPACING);
 
@@ -884,7 +884,7 @@ PtWidget_t * AP_QNXDialog_Paragraph::_constructWindow(void)
 
 	/* Now at the bottom add in some buttons ... */
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_ButtonTabs ).c_str());
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Para_ButtonTabs ).utf8_str());
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, unixstr, 0);
 	PtSetArg(&args[n++], Pt_ARG_FLAGS,Pt_TRUE,Pt_GHOST|Pt_BLOCKED);
 	buttonTabs = PtCreateWidget(PtButton, hbuttongroup, n, args);
@@ -897,14 +897,14 @@ PtWidget_t * AP_QNXDialog_Paragraph::_constructWindow(void)
 
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(XAP_STRING_ID_DLG_OK ).c_str());
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(XAP_STRING_ID_DLG_OK ).utf8_str());
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, unixstr, 0);
 	buttonOK = PtCreateWidget(PtButton, hbuttongroup, n, args);
 	FREEP(unixstr);
 
 	n = 0;
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, ABI_DEFAULT_BUTTON_WIDTH, 0);
-	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(XAP_STRING_ID_DLG_Cancel ).c_str());
+	UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(XAP_STRING_ID_DLG_Cancel ).utf8_str());
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, unixstr, 0);
 	buttonCancel = PtCreateWidget(PtButton, hbuttongroup, n, args);
 	FREEP(unixstr);
