@@ -115,7 +115,7 @@ GtkWidget * AP_UnixDialog_Break::_constructWindow(void)
 	m_radioGroup = gtk_radio_button_get_group (GTK_RADIO_BUTTON ( glade_xml_get_widget(xml, "rbPageBreak") ));
 
 	// set the dialog title
-	abiDialogSetTitle(window, pSS->getValueUTF8(AP_STRING_ID_DLG_Break_BreakTitle_Capital).c_str());
+	abiDialogSetTitle(window, pSS->getValueUTF8(AP_STRING_ID_DLG_Break_BreakTitle_Capital).utf8_str());
 	
 	// localize the strings in our dialog, and set tags for some widgets
 	
