@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
  * 02111-1307, USA.
  */
-
+#undef GTK_DISABLE_DEPRECATED
 #include <stdlib.h>
 #include <time.h>
 
@@ -155,7 +155,7 @@ void  AP_UnixDialog_InsertBookmark::_constructWindowContents(GtkWidget * contain
   GtkWidget *label1;
   const XAP_StringSet * pSS = m_pApp->getStringSet();
 
-  label1 = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_InsertBookmark_Msg).c_str());
+  label1 = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_InsertBookmark_Msg).utf8_str());
   gtk_widget_show (label1);
   gtk_box_pack_start (GTK_BOX (container), label1, FALSE, FALSE, 0);
 
@@ -174,7 +174,7 @@ GtkWidget*  AP_UnixDialog_InsertBookmark::_constructWindow(void)
 
   const XAP_StringSet * pSS = m_pApp->getStringSet();
 
-  m_windowMain = abiDialogNew("insert bookmark dialog", TRUE, pSS->getValueUTF8(AP_STRING_ID_DLG_InsertBookmark_Title).c_str());
+  m_windowMain = abiDialogNew("insert bookmark dialog", TRUE, pSS->getValueUTF8(AP_STRING_ID_DLG_InsertBookmark_Title).utf8_str());
 
   
   vbox = gtk_vbox_new (FALSE, 6);
