@@ -17,6 +17,7 @@
  * 02111-1307, USA.
  */
 
+#undef GTK_DISABLE_DEPRECATED
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
@@ -154,6 +155,7 @@ static gboolean s_update (void)
 
 void AP_UnixDialog_Lists::closeClicked(void)
 {
+	setAnswer(AP_Dialog_Lists::a_QUIT);	
 	abiDestroyWidget(m_wMainWindow); // emit the correct signals
 }
 
@@ -195,9 +197,10 @@ void AP_UnixDialog_Lists::runModal( XAP_Frame * pFrame)
 	setNewListType(savedListType);
 	
 	abiRunModalDialog ( GTK_DIALOG(mainWindow), pFrame, this, BUTTON_CANCEL, false );
-	
+	AP_Dialog_Lists::tAnswer res = getAnswer();
 	g_list_free( m_glFonts);
 	abiDestroyWidget ( mainWindow ) ;
+	setAnswer(res);
 	DELETEP (m_pPreviewWidget);
 }
 
@@ -454,6 +457,7 @@ void  AP_UnixDialog_Lists::applyClicked(void)
 	if(isModal())
 	{
 		setAnswer(AP_Dialog_Lists::a_OK);
+		
 	}
 }
 
@@ -539,7 +543,7 @@ void AP_UnixDialog_Lists::_fillFontMenu(GtkWidget* menu)
         // this you get whatever font is in the document at the point the
         // list is inserted.
 
-	glade_menuitem = gtk_menu_item_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Current_Font).c_str());
+	glade_menuitem = gtk_menu_item_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Current_Font).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data (G_OBJECT (glade_menuitem), "user_data", GINT_TO_POINTER (0));
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), glade_menuitem);
@@ -643,17 +647,17 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 					  (GtkAttachOptions) (0), 0, 0);
 
 	type_om_menu = gtk_menu_new ();
-	GtkWidget * menu_none = gtk_menu_item_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type_none).c_str());
+	GtkWidget * menu_none = gtk_menu_item_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type_none).utf8_str());
 	m_wMenu_None = menu_none;
 	g_object_set_data(G_OBJECT(menu_none),"user_data",GINT_TO_POINTER(0));
 	gtk_widget_show (menu_none);
 	gtk_menu_shell_append (GTK_MENU_SHELL (type_om_menu), menu_none);
-	GtkWidget * menu_bull  = gtk_menu_item_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type_bullet).c_str());
+	GtkWidget * menu_bull  = gtk_menu_item_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type_bullet).utf8_str());
 	g_object_set_data(G_OBJECT(menu_bull),"user_data",GINT_TO_POINTER(1));
 	gtk_widget_show (menu_bull);
 	m_wMenu_Bull = menu_bull;
 	gtk_menu_shell_append (GTK_MENU_SHELL (type_om_menu), menu_bull);
-	GtkWidget * menu_num  = gtk_menu_item_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type_numbered).c_str());
+	GtkWidget * menu_num  = gtk_menu_item_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type_numbered).utf8_str());
 	g_object_set_data(G_OBJECT(menu_num),"user_data",GINT_TO_POINTER(2));
 	gtk_widget_show (menu_num);
 	m_wMenu_Num = menu_num;
@@ -665,21 +669,21 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 	gtk_option_menu_set_history (GTK_OPTION_MENU (type_om), 2);
 	gtk_widget_set_events(type_om, GDK_ALL_EVENTS_MASK);
 
-	type_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type).c_str());
+	type_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type).utf8_str());
 	gtk_widget_show (type_lb);
 	gtk_table_attach (GTK_TABLE (table1), type_lb, 0, 1, 0, 1,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (type_lb), 0, 0.5);
 
-	style_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Style).c_str());
+	style_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Style).utf8_str());
 	gtk_widget_show (style_lb);
 	gtk_table_attach (GTK_TABLE (table1), style_lb, 0, 1, 1, 2,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (style_lb), 0, 0.5);
 
-	customized_cb = gtk_button_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_SetDefault).c_str());
+	customized_cb = gtk_button_new_with_label (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_SetDefault).utf8_str());
 	gtk_widget_show (customized_cb);
 	gtk_table_attach (GTK_TABLE (table1), customized_cb, 0, 2, 2, 3,
 					  (GtkAttachOptions) (GTK_SHRINK),
@@ -749,42 +753,42 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 	gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (label_align_sb), TRUE);
 	gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (label_align_sb), TRUE);
 
-	format_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Format).c_str());
+	format_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Format).utf8_str());
 	gtk_widget_show (format_lb);
 	gtk_table_attach (GTK_TABLE (table2), format_lb, 0, 1, 0, 1,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (format_lb), 0.0, 0.5);
 
-	font_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Font).c_str());
+	font_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Font).utf8_str());
 	gtk_widget_show (font_lb);
 	gtk_table_attach (GTK_TABLE (table2), font_lb, 0, 1, 1, 2,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (font_lb), 0.0, 0.5);
 
-	delimiter_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_DelimiterString).c_str());
+	delimiter_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_DelimiterString).utf8_str());
 	gtk_widget_show (delimiter_lb);
 	gtk_table_attach (GTK_TABLE (table2), delimiter_lb, 0, 1, 2, 3,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (delimiter_lb), 0.0, 0.5);
 
-	start_at_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Start).c_str());
+	start_at_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Start).utf8_str());
 	gtk_widget_show (start_at_lb);
 	gtk_table_attach (GTK_TABLE (table2), start_at_lb, 0, 1, 3, 4,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (start_at_lb), 0.0, 0.5);
 
-	text_align_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Align).c_str());
+	text_align_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Align).utf8_str());
 	gtk_widget_show (text_align_lb);
 	gtk_table_attach (GTK_TABLE (table2), text_align_lb, 0, 1, 4, 5,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (text_align_lb), 0.0, 0.5);
 
-	label_align_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Indent).c_str());
+	label_align_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Indent).utf8_str());
 	gtk_widget_show (label_align_lb);
 	gtk_table_attach (GTK_TABLE (table2), label_align_lb, 0, 1, 5, 6,
 					  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
@@ -795,7 +799,7 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 	gtk_widget_show (vbox3);
 	gtk_box_pack_start (GTK_BOX (hbox2), vbox3, TRUE, TRUE, 0);
 
-	preview_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Preview).c_str());
+	preview_lb = gtk_label_new (pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Preview).utf8_str());
 	gtk_widget_show (preview_lb);
 	gtk_box_pack_start (GTK_BOX (vbox3), preview_lb, FALSE, FALSE, 0);
 	gtk_misc_set_alignment (GTK_MISC (preview_lb), 0.0, 0.5);
@@ -816,20 +820,20 @@ GtkWidget *AP_UnixDialog_Lists::_constructWindowContents (void)
 		gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox1, FALSE, FALSE, 0);
 
-	start_list_rb = gtk_radio_button_new_with_label (action_group, pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Start_New).c_str());
+	start_list_rb = gtk_radio_button_new_with_label (action_group, pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Start_New).utf8_str());
 	action_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (start_list_rb));
 	if(!isModal())
 		gtk_widget_show (start_list_rb);
 	gtk_box_pack_start (GTK_BOX (hbox1), start_list_rb, FALSE, FALSE, 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (start_list_rb), TRUE);
 
-	apply_list_rb = gtk_radio_button_new_with_label (action_group, pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Apply_Current).c_str());
+	apply_list_rb = gtk_radio_button_new_with_label (action_group, pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Apply_Current).utf8_str());
 	action_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (apply_list_rb));
 	if(!isModal())
 		gtk_widget_show (apply_list_rb);
 	gtk_box_pack_start (GTK_BOX (hbox1), apply_list_rb, FALSE, FALSE, 0);
 
-	resume_list_rb = gtk_radio_button_new_with_label (action_group, pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Resume).c_str());
+	resume_list_rb = gtk_radio_button_new_with_label (action_group, pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Resume).utf8_str());
 	action_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (resume_list_rb));
 	if(!isModal())
 		gtk_widget_show (resume_list_rb);
@@ -915,7 +919,7 @@ void AP_UnixDialog_Lists::_fillNoneStyleMenu( GtkWidget *listmenu)
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type_none).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Type_none).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data", GINT_TO_POINTER(
 		static_cast<gint>(NOT_A_LIST) ));
@@ -930,7 +934,7 @@ void AP_UnixDialog_Lists::_fillNumberedStyleMenu( GtkWidget *listmenu)
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Numbered_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Numbered_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(NUMBERED_LIST) ));
@@ -940,7 +944,7 @@ void AP_UnixDialog_Lists::_fillNumberedStyleMenu( GtkWidget *listmenu)
 
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Lower_Case_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Lower_Case_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(LOWERCASE_LIST)));
@@ -949,7 +953,7 @@ void AP_UnixDialog_Lists::_fillNumberedStyleMenu( GtkWidget *listmenu)
 						G_CALLBACK (s_typeChanged), this);
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Upper_Case_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Upper_Case_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(UPPERCASE_LIST)));
@@ -958,7 +962,7 @@ void AP_UnixDialog_Lists::_fillNumberedStyleMenu( GtkWidget *listmenu)
 						G_CALLBACK (s_typeChanged), this);
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Lower_Roman_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Lower_Roman_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(LOWERROMAN_LIST)));
@@ -967,7 +971,7 @@ void AP_UnixDialog_Lists::_fillNumberedStyleMenu( GtkWidget *listmenu)
 						G_CALLBACK (s_typeChanged), this);
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Upper_Roman_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Upper_Roman_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(UPPERROMAN_LIST)));
@@ -976,7 +980,7 @@ void AP_UnixDialog_Lists::_fillNumberedStyleMenu( GtkWidget *listmenu)
 						G_CALLBACK (s_typeChanged), this);
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Arabic_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Arabic_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(ARABICNUMBERED_LIST)));
@@ -984,7 +988,7 @@ void AP_UnixDialog_Lists::_fillNumberedStyleMenu( GtkWidget *listmenu)
 	g_signal_connect (G_OBJECT (glade_menuitem), "activate",
 						G_CALLBACK (s_typeChanged), this);
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Hebrew_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Hebrew_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(HEBREW_LIST)));
@@ -1000,7 +1004,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Bullet_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Bullet_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(BULLETED_LIST)));
@@ -1009,7 +1013,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 						G_CALLBACK (s_typeChanged), this);
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Dashed_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Dashed_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(DASHED_LIST)));
@@ -1019,7 +1023,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Square_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Square_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(SQUARE_LIST)));
@@ -1029,7 +1033,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Triangle_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Triangle_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(TRIANGLE_LIST)));
@@ -1038,7 +1042,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 						G_CALLBACK (s_typeChanged), this);
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Diamond_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Diamond_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(DIAMOND_LIST)));
@@ -1048,7 +1052,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Star_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Star_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(STAR_LIST)));
@@ -1058,7 +1062,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Implies_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Implies_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(IMPLIES_LIST)));
@@ -1068,7 +1072,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Tick_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Tick_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(TICK_LIST)));
@@ -1078,7 +1082,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Box_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Box_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(BOX_LIST)));
@@ -1089,7 +1093,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Hand_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Hand_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(HAND_LIST)));
@@ -1098,7 +1102,7 @@ void AP_UnixDialog_Lists::_fillBulletedStyleMenu( GtkWidget *listmenu)
 						G_CALLBACK (s_typeChanged), this);
 
 	glade_menuitem = gtk_menu_item_new_with_label (
-		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Heart_List).c_str());
+		pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Heart_List).utf8_str());
 	gtk_widget_show (glade_menuitem);
 	g_object_set_data(G_OBJECT(glade_menuitem),"user_data",GINT_TO_POINTER(
 		static_cast<gint>(HEART_LIST)));
@@ -1114,14 +1118,15 @@ void AP_UnixDialog_Lists::_setRadioButtonLabels(void)
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 	PopulateDialogData();
 	// Button 0 is Start New List, button 2 is resume list
-	gtk_label_set_text( GTK_LABEL(m_wStartNew_label), pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Start_New).c_str());
-	gtk_label_set_text( GTK_LABEL(m_wStartSub_label), pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Resume).c_str());
+	gtk_label_set_text( GTK_LABEL(m_wStartNew_label), pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Start_New).utf8_str());
+	gtk_label_set_text( GTK_LABEL(m_wStartSub_label), pSS->getValueUTF8(AP_STRING_ID_DLG_Lists_Resume).utf8_str());
 }
 
 static void s_destroy_clicked(GtkWidget * /* widget */,
 			      AP_UnixDialog_Lists * dlg)
 {
 	UT_ASSERT(dlg);
+	dlg->setAnswer(AP_Dialog_Lists::a_QUIT);
 	dlg->destroy();
 }
 
