@@ -137,7 +137,7 @@ GtkWidget * AP_UnixDialog_Spell::_constructWindow(void)
 
     const XAP_StringSet * pSS = m_pApp->getStringSet();
    
-    windowSpell = abiDialogNew("spelling dialog", TRUE, pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_SpellTitle).c_str());
+    windowSpell = abiDialogNew("spelling dialog", TRUE, pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_SpellTitle).utf8_str());
 
     // *very* important to add the vbox
     // to the window so that it gets a
@@ -151,22 +151,22 @@ GtkWidget * AP_UnixDialog_Spell::_constructWindow(void)
     m_buttonCancel = abiAddStockButton(GTK_DIALOG(windowSpell), GTK_STOCK_CANCEL, BUTTON_CANCEL);
 
     UT_XML_cloneNoAmpersands(unixstr,
-                             pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_Change).c_str());
+                             pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_Change).utf8_str());
     m_buttonChange = abiAddButton (GTK_DIALOG(windowSpell), unixstr, BUTTON_CHANGE);
     FREEP(unixstr);
   
     UT_XML_cloneNoAmpersands(unixstr, 
-                             pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_ChangeAll).c_str());
+                             pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_ChangeAll).utf8_str());
     m_buttonChangeAll = abiAddButton (GTK_DIALOG(windowSpell), unixstr, BUTTON_CHANGE_ALL);
     FREEP(unixstr);
 
     UT_XML_cloneNoAmpersands(unixstr, 
-                             pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_Ignore).c_str());
+                             pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_Ignore).utf8_str());
     m_buttonIgnore = abiAddButton (GTK_DIALOG(windowSpell), unixstr, BUTTON_IGNORE);
     FREEP(unixstr);
 
     UT_XML_cloneNoAmpersands(unixstr, 
-                             pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_IgnoreAll).c_str());
+                             pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_IgnoreAll).utf8_str());
     m_buttonIgnoreAll = abiAddButton (GTK_DIALOG(windowSpell), unixstr, BUTTON_IGNORE_ALL);
     FREEP(unixstr);
 
@@ -205,7 +205,7 @@ void AP_UnixDialog_Spell::_constructWindowContents(GtkWidget *box)
     GtkWidget * alignmentLabel = gtk_alignment_new (0, 1, 0, 0);
     gtk_table_attach (GTK_TABLE(tableMain), alignmentLabel, 0, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 
-    UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_UnknownWord).c_str());
+    UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_UnknownWord).utf8_str());
     label1 = gtk_label_new (unixstr);
     FREEP(unixstr);
     gtk_label_set_justify (GTK_LABEL(label1), GTK_JUSTIFY_LEFT);
@@ -229,7 +229,7 @@ void AP_UnixDialog_Spell::_constructWindowContents(GtkWidget *box)
     GtkWidget * hboxChangeTo = gtk_hbox_new(FALSE, 5);
     gtk_table_attach_defaults (GTK_TABLE(tableMain), hboxChangeTo, 0, 2, 5, 6);
 
-    UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_ChangeTo).c_str());
+    UT_XML_cloneNoAmpersands(unixstr, pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_ChangeTo).utf8_str());
     label2 = gtk_label_new (unixstr);
     FREEP(unixstr);
     gtk_box_pack_start (GTK_BOX(hboxChangeTo), label2, FALSE, FALSE, 5);
@@ -339,7 +339,7 @@ void AP_UnixDialog_Spell::_showMisspelledWord(void)
     if (!m_Suggestions->getItemCount()) {
 
         const XAP_StringSet * pSS = m_pApp->getStringSet();
-        UT_XML_cloneNoAmpersands(suggest[0], pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_NoSuggestions).c_str());
+        UT_XML_cloneNoAmpersands(suggest[0], pSS->getValueUTF8(AP_STRING_ID_DLG_Spell_NoSuggestions).utf8_str());
         gtk_clist_append( GTK_CLIST(m_clistSuggestions), suggest);
         FREEP(suggest[0]);
         gtk_clist_set_selectable(GTK_CLIST(m_clistSuggestions), 0, FALSE);
