@@ -38,6 +38,13 @@ class AP_UnixDialog_ToggleCase: public AP_Dialog_ToggleCase
 	static XAP_Dialog *		static_constructor(XAP_DialogFactory *, XAP_Dialog_Id id);
 
  protected:
+
+	typedef enum
+		{
+			BUTTON_OK,
+			BUTTON_CANCEL
+		} ResponseId ;
+	
 	virtual GtkWidget * _constructWindow(void);
 	virtual void        _constructWindowContents (GtkWidget *parent);
 	
