@@ -85,8 +85,7 @@ void AP_Dialog_Goto::ConstructWindowName(void)
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
 	XML_Char * tmp = NULL;
 	UT_uint32 title_width = 33;
-	UT_String sTitle(pSS->getValueUTF8(AP_STRING_ID_DLG_Goto_Title));
-	UT_XML_cloneNoAmpersands(tmp, sTitle.c_str() );
+	UT_XML_cloneNoAmpersands(tmp, pSS->getValueUTF8(AP_STRING_ID_DLG_Goto_Title).utf8_str());
 	BuildWindowName((char *) m_WindowName,(char*)tmp,title_width);
 	FREEP(tmp);
 }							
