@@ -34,6 +34,7 @@
 #include "xap_Frame.h"
 #include "xap_Prefs.h"
 #include "xav_View.h"
+#include "xap_Toolbar_Layouts.h"
 #include "fv_View.h"
 #include "ap_FrameData.h"
 #include "ap_Prefs.h"
@@ -42,6 +43,10 @@
 #include "spell_manager.h"
 #include "ie_mailmerge.h"
 
+#ifdef _WIN32
+#include "ap_Win32App.h" 
+#endif
+
 #define ABIWORD_VIEW  	FV_View * pView = static_cast<FV_View *>(pAV_View)
 
 /*****************************************************************/
@@ -147,6 +152,35 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Autotext)
 	return c;
 }
 
+Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Toolbar)
+{
+	UT_ASSERT(pFrame);
+	XAP_App * pApp = pFrame->getApp();
+	UT_ASSERT(pApp);
+	UT_ASSERT(pLabel);
+
+	UT_ASSERT(id >= AP_MENU_ID_VIEW_TB_1);
+	UT_ASSERT(id <= AP_MENU_ID_VIEW_TB_4);
+
+	UT_uint32 ndx = (id - AP_MENU_ID_VIEW_TB_1);
+	const UT_Vector & vec = pApp->getToolbarFactory()->getToolbarNames();
+
+
+	if (ndx <= vec.getItemCount())
+	{
+		const char * szFormat = pLabel->getMenuLabel();
+		static char buf[128];	
+		
+		const char * szRecent = reinterpret_cast<const UT_UTF8String*>(vec.getNthItem(ndx))->utf8_str();
+
+		snprintf(buf,sizeof(buf),szFormat,szRecent);
+		return buf;
+	}
+
+	return NULL;
+}
+
+
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Recent)
 {
 	// Compute the menu label for _recent_1 thru _recent_9 on the menu.
@@ -500,7 +534,7 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Suggest)
 			outbuf += unichar_to_utf8(p[i], reinterpret_cast<unsigned char *>(outbuf));
 		}
 		*outbuf = 0;
-		c = cBuf;
+		c = cBuf;		
 	}
 	else if (ndx == 1)
 	{
@@ -720,7 +754,7 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_CharFmt)
 	const XML_Char * prop = NULL;
 	const XML_Char * val  = NULL;
 
-	if(pView->getDocument()->areStylesLocked() && (AP_MENU_ID_FMT_SUPERSCRIPT != id || AP_MENU_ID_FMT_SUBSCRIPT != id)) {
+	if(pView->getDocument()->areStylesLocked() && !(AP_MENU_ID_FMT_SUPERSCRIPT == id || AP_MENU_ID_FMT_SUBSCRIPT == id)) {
           return EV_MIS_Gray;
 	}
 
@@ -775,6 +809,16 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_CharFmt)
 		val  = "subscript";
 		break;
 
+	case AP_MENU_ID_FMT_DIRECTION_DO_RTL:
+		prop = "dir-override";
+		val  = "rtl";
+		break;
+		
+	case AP_MENU_ID_FMT_DIRECTION_DO_LTR:
+		prop = "dir-override";
+		val  = "ltr";
+		break;
+
 	default:
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		break;
@@ -844,6 +888,11 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_BlockFmt)
 		val  = "justify";
 		break;
 
+	case AP_MENU_ID_FMT_DIRECTION_DD_RTL:
+		prop = "dom-dir";
+		val  = "rtl";
+		break;
+
 	default:
 		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 		break;
@@ -904,25 +953,25 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_View)
 		else
 			s = EV_MIS_Toggled;
 		break;
-	case AP_MENU_ID_VIEW_TB_STD:
+	case AP_MENU_ID_VIEW_TB_1:
 		if ( pFrameData->m_bShowBar[0] && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
 		else
 			s = EV_MIS_ZERO;
 		break;
-	case AP_MENU_ID_VIEW_TB_FORMAT:
+	case AP_MENU_ID_VIEW_TB_2:	
 		if ( pFrameData->m_bShowBar[1] && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
 		else
 			s = EV_MIS_ZERO;
 		break;
-	case AP_MENU_ID_VIEW_TB_TABLE:
+	case AP_MENU_ID_VIEW_TB_3:	
 		if ( pFrameData->m_bShowBar[2] && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
 		else
 			s = EV_MIS_ZERO;
 		break;
-	case AP_MENU_ID_VIEW_TB_EXTRA:
+	case AP_MENU_ID_VIEW_TB_4:	
 		if ( pFrameData->m_bShowBar[3] && !pFrameData->m_bIsFullScreen)
 			s = EV_MIS_Toggled;
 		else
