@@ -32,7 +32,7 @@
 #include "ap_Strings.h"
 #include "ap_Dialog_Lists.h"
 
-#include <fribidi/fribidi.h>
+#include <fribidi.h>
 
 /************************************************************************/
 
@@ -122,7 +122,7 @@ void AP_Preview_Paragraph_Block::setText(const UT_UCSChar * text)
 			m_words.addItem(clone);
 
 			// measure clone item
-			m_widths.addItem((void *) m_gc->measureString(clone, 0, UT_UCS4_strlen(clone), NULL));
+			m_widths.addItem(m_gc->measureString(clone, 0, UT_UCS4_strlen(clone), NULL));
 
 			// advance clone pointer for new word
 			clone = i + 1;
@@ -133,7 +133,7 @@ void AP_Preview_Paragraph_Block::setText(const UT_UCSChar * text)
 	// add last word
 	m_words.addItem(clone);
 	// measure last word
-	m_widths.addItem((void *) m_gc->measureString(clone, 0, UT_UCS4_strlen(clone), NULL));
+	m_widths.addItem(m_gc->measureString(clone, 0, UT_UCS4_strlen(clone), NULL));
 }
 
 // ignores NULL parameters, otherwise scales dimensioned strings into
@@ -332,18 +332,12 @@ AP_Preview_Paragraph::AP_Preview_Paragraph(GR_Graphics * gc,
 
 	const XAP_StringSet * pSS = dlg->getApp()->getStringSet();
 
-	UT_UCSChar * tmp = NULL;
-
-	UT_UCS4_cloneString_char(&tmp, pSS->getValue(AP_STRING_ID_DLG_Para_PreviewPrevParagraph));
-	m_previousBlock->setText(tmp);
-	FREEP(tmp);
+	m_previousBlock->setText(pSS->getValueUTF8(AP_STRING_ID_DLG_Para_PreviewPrevParagraph).ucs4_str().ucs4_str());
 
 	// this text came from the current document, passed in as arg
 	m_activeBlock->setText(text);
 
-	UT_UCS4_cloneString_char(&tmp, pSS->getValue(AP_STRING_ID_DLG_Para_PreviewFollowParagraph));
-	m_followingBlock->setText(tmp);
-	FREEP(tmp);
+	m_followingBlock->setText(pSS->getValueUTF8(AP_STRING_ID_DLG_Para_PreviewFollowParagraph).ucs4_str().ucs4_str());
 }
 
 AP_Preview_Paragraph::AP_Preview_Paragraph(GR_Graphics * gc,
@@ -392,19 +386,12 @@ AP_Preview_Paragraph::AP_Preview_Paragraph(GR_Graphics * gc,
 
 	const XAP_StringSet * pSS = dlg->getApp()->getStringSet();
 
-	UT_UCSChar * tmp = NULL;
-
-	UT_UCS4_cloneString_char(&tmp, pSS->getValue(AP_STRING_ID_DLG_Para_PreviewPrevParagraph));
-	m_previousBlock->setText(tmp);
-	FREEP(tmp);
+	m_previousBlock->setText(pSS->getValueUTF8(AP_STRING_ID_DLG_Para_PreviewPrevParagraph).ucs4_str().ucs4_str());
 
 	// this text came from the current document, passed in as arg
 	m_activeBlock->setText(text);
 
-	UT_UCS4_cloneString_char(&tmp, pSS->getValue(AP_STRING_ID_DLG_Para_PreviewFollowParagraph));
-	m_followingBlock->setText(tmp);
-	FREEP(tmp);
-
+	m_followingBlock->setText(pSS->getValueUTF8(AP_STRING_ID_DLG_Para_PreviewFollowParagraph).ucs4_str().ucs4_str());
 }
 
 AP_Preview_Paragraph::AP_Preview_Paragraph(GR_Graphics * gc,
@@ -481,19 +468,12 @@ AP_Preview_Paragraph::AP_Preview_Paragraph(GR_Graphics * gc,
 
 	const XAP_StringSet * pSS = dlg->m_pApp->getStringSet();
 
-
-	UT_UCSChar * tmp = NULL;
-
-	UT_UCS4_cloneString_char(&tmp, pSS->getValue(AP_STRING_ID_DLG_Para_PreviewPrevParagraph));
-	m_previousBlock->setText(tmp);
-	FREEP(tmp);
+	m_previousBlock->setText(pSS->getValueUTF8(AP_STRING_ID_DLG_Para_PreviewPrevParagraph).ucs4_str().ucs4_str());
 
 	// this text came from the current document, passed in as arg
 	m_activeBlock->setText(text);
 
-	UT_UCS4_cloneString_char(&tmp, pSS->getValue(AP_STRING_ID_DLG_Para_PreviewFollowParagraph));
-	m_followingBlock->setText(tmp);
-	FREEP(tmp);
+	m_followingBlock->setText(pSS->getValueUTF8(AP_STRING_ID_DLG_Para_PreviewFollowParagraph).ucs4_str().ucs4_str());
 }
 
 AP_Preview_Paragraph::~AP_Preview_Paragraph()
@@ -663,7 +643,7 @@ void AP_Preview_Paragraph::_appendBlock(AP_Preview_Paragraph_Block * block)
 
 // returns number of words it plotted
 UT_uint32 AP_Preview_Paragraph::_appendLine(UT_Vector * words,
-											UT_Vector * widths,
+											UT_NumberVector * widths,
 											UT_uint32 startWithWord,
 											UT_uint32 left,
 											UT_uint32 right,
@@ -695,9 +675,9 @@ UT_uint32 AP_Preview_Paragraph::_appendLine(UT_Vector * words,
 	// NOTE : we don't evaluate space widths in the while() condition so we don't
 	// NOTE : wrap on one (which would be silly)
 	while ((i < totalWords) &&
-		   (pixelsForThisLine + (UT_uint32) widths->getNthItem(i) <= (UT_uint32)maxPixelsForThisLine))
+		   (pixelsForThisLine + widths->getNthItem(i) <= (UT_uint32)maxPixelsForThisLine))
 	{
-		pixelsForThisLine += (UT_uint32) widths->getNthItem(i) + spaceCharWidth;
+		pixelsForThisLine += widths->getNthItem(i) + spaceCharWidth;
 		i++;
 	}
 
@@ -705,7 +685,7 @@ UT_uint32 AP_Preview_Paragraph::_appendLine(UT_Vector * words,
 	{
 		// HACK: Make sure we have at least one word. (no longer true, because of above)
 
-		pixelsForThisLine += (UT_uint32) widths->getNthItem(i) + spaceCharWidth;
+		pixelsForThisLine += widths->getNthItem(i) + spaceCharWidth;
 		i++;
 	}
 
@@ -779,12 +759,12 @@ UT_uint32 AP_Preview_Paragraph::_appendLine(UT_Vector * words,
 		    str[j] = (UT_UCSChar)fb2[j];
 
 		if(m_dir == FRIBIDI_TYPE_RTL)
-		    willDrawAt -= (((UT_uint32) widths->getNthItem(k)) << 8) + spaceCharWidth;
+		    willDrawAt -= ((widths->getNthItem(k)) << 8) + spaceCharWidth;
 
 		m_gc->drawChars(str, 0,	iLen, willDrawAt >> 8, y);
 
 		if(m_dir == FRIBIDI_TYPE_LTR)
-		    willDrawAt += (((UT_uint32) widths->getNthItem(k)) << 8) + spaceCharWidth;
+		    willDrawAt += ((widths->getNthItem(k)) << 8) + spaceCharWidth;
 	}
 
 	// return number of words drawn
