@@ -35,7 +35,7 @@
 #include "fl_AutoLists.h"
 #include "fl_AutoNum.h"
 #include "fl_BlockLayout.h"
-#include <fribidi/fribidi.h>
+#include <fribidi.h>
 #include  "ie_Table.h"
 
 class IE_Imp_RTF;
@@ -197,9 +197,9 @@ struct ABI_EXPORT RTFProps_ParaProps
     UT_sint32	m_indentFirst;	// first line indent in twips
 	double	m_lineSpaceVal;		// line spaceing value
 	bool	m_lineSpaceExact;	// TRUE if m_lineSpaceVal is an exact value, FALSE if multiple
-	UT_Vector m_tabStops;
-	UT_Vector m_tabTypes;
-	UT_Vector m_tabLeader;
+	UT_NumberVector m_tabStops;
+	UT_NumberVector m_tabTypes;
+	UT_NumberVector m_tabLeader;
 	bool         m_isList;       // TRUE if para is an element of a list
 	UT_sint32       m_level;        // Level of list in para
 	char            m_pszStyle[30]; // Type of List
@@ -326,9 +326,9 @@ public:
 	RTFProps_bCharProps * m_pbCharProps;
 	bool setList(void);
 	bool isTab(UT_uint32 iLevel);
-	UT_Vector * getTabStopVect(UT_uint32 iLevel);
-	UT_Vector * getTabTypeVect(UT_uint32 iLevel);
-	UT_Vector * getTabLeaderVect(UT_uint32 iLevel);
+	UT_NumberVector * getTabStopVect(UT_uint32 iLevel);
+	UT_NumberVector * getTabTypeVect(UT_uint32 iLevel);
+	UT_NumberVector * getTabLeaderVect(UT_uint32 iLevel);
 	bool isDeletedChanged(UT_uint32 iLevel);
 	bool getDeleted(UT_uint32 iLevel);
 	bool isBoldChanged(UT_uint32 iLevel);
@@ -559,10 +559,11 @@ private:
 	bool ParseChar(UT_UCSChar ch,bool no_convert=1);
 	bool ReadCharFromFileWithCRLF(unsigned char* pCh);
 	bool ReadCharFromFile(unsigned char* pCh);
+	UT_UCS4Char ReadHexChar(void);
 	bool SkipBackChar(unsigned char ch);
-	bool ReadKeyword(unsigned char* pKeyword, long* pParam, bool* pParamUsed,
+	bool ReadKeyword(unsigned char* pKeyword, UT_sint16* pParam, bool* pParamUsed,
 					 UT_uint32 keywordBuffLen);
-	bool TranslateKeyword(unsigned char* pKeyword, long param, bool fParam);
+	bool TranslateKeyword(unsigned char* pKeyword, UT_sint16 param, bool fParam);
 	bool ReadColourTable();
 	bool ReadFontTable();
 	bool ReadOneFontFromTable();
@@ -588,7 +589,7 @@ private:
 	bool HandleListLevel(RTF_msword97_list * pList, UT_uint32 levelCount  );
 	bool HandleTableList(void);
 	char * getCharsInsideBrace(void);
-	bool ParseCharParaProps( unsigned char * pKeyword, long param, bool fParam, RTFProps_CharProps * pChars, RTFProps_ParaProps * pParas, RTFProps_bCharProps * pbChars, RTFProps_bParaProps * pbParas);
+	bool ParseCharParaProps( unsigned char * pKeyword, UT_sint16 param, bool fParam, RTFProps_CharProps * pChars, RTFProps_ParaProps * pParas, RTFProps_bCharProps * pbChars, RTFProps_bParaProps * pbParas);
 	bool ReadListOverrideTable(void);
 	bool HandleTableListOverride(void);
 
@@ -678,7 +679,7 @@ private:
 	    RTF_TOKEN_DATA,
 	    RTF_TOKEN_ERROR = -1
 	} RTFTokenType;
-	RTFTokenType NextToken (unsigned char *pKeyword, long* pParam,
+	RTFTokenType NextToken (unsigned char *pKeyword, UT_sint16* pParam,
 							bool* pParamUsed, UT_uint32 len, bool bIgnoreWhiteSpace=false);
 
 	UT_Error _isBidiDocument();
@@ -715,7 +716,7 @@ private:
 	RTFStateStore m_currentRTFState;
 
 	UT_Vector m_fontTable;
-	UT_Vector m_colourTable;
+	UT_NumberVector m_colourTable;
 	UT_Vector m_hdrFtrTable;
 	UT_Vector m_styleTable;
 
@@ -783,6 +784,7 @@ private:
 	UT_sint32             m_iNoCellsSinceLastRow;
 	RTFStateStore         m_FootnoteRefState;
 	bool                  m_bFieldRecognized;
+	UT_sint32             m_iIsInHeaderFooter;
 };
 
 #endif /* IE_IMP_RTF_H */
